clear all
#delimit;
version 16.1;

set more off;

*LIKELIHOOD EVALUATORS AND PROGRAMS IMPLEMENTED IN THE MONTE CARLO STUDY; 

program HAS_Probit_lf2;
	version 16.1;
	args todo b lnfj g1 g2 g3 H;
	tempvar z1 q1 w1 cc A;
	tempname eta0 eta1 alp0 alp1;
	mleval `z1' = `b', eq(1);
	mleval `eta0' = `b', eq(2) scalar;
	mleval `eta1' = `b', eq(3) scalar;
	quietly {;
		generate double `q1' = (2*$ML_y1) - 1;
		generate double `w1' = `q1'*`z1';
		scalar `alp0' = exp(`eta0')/(1+exp(`eta0')+exp(`eta1'));
		scalar `alp1' = exp(`eta1')/(1+exp(`eta0')+exp(`eta1'));
		generate double `cc' = (`alp0'*$ML_y1) + (`alp1'*(1-$ML_y1));
		generate double `A' = `cc' + ((1-`alp0'-`alp1')*normal(`w1'));
		replace `lnfj' = ln(`A');
		if (`todo'==0) exit;
		replace `g1' = (1-`alp0'-`alp1')*`q1'*normalden(`w1')/`A';
		replace `g2' = `alp0'*($ML_y1-`A')/`A';
		replace `g3' = `alp1'*(1-$ML_y1-`A')/`A';
		if (`todo'==1) exit;
		tempvar h11 h12 h13 h22 h23 h33;
		gen double `h11' = -(1-`alp0'-`alp1')*normalden(`w1')*(`w1'+((1-`alp0'-`alp1')*normalden(`w1')/`A'))/`A';
		gen double `h12' = -`alp0'*(1-`alp0'-`alp1')*`q1'*normalden(`w1')*$ML_y1/(`A'^2);
		gen double `h13' = -`alp1'*(1-`alp0'-`alp1')*`q1'*normalden(`w1')*(1-$ML_y1)/(`A'^2);
		gen double `h22' = `alp0'*($ML_y1-`A')*(1-(2*`alp0')-(`alp0'*($ML_y1-`A')/`A'))/`A';
		gen double `h23' = `alp0'*`alp1';
		gen double `h33' = `alp1'*(1-$ML_y1-`A')*(1-(2*`alp1')-(`alp1'*(1-$ML_y1-`A')/`A'))/`A';
		tempname d11 d12 d13 d22 d23 d33;
		mlmatsum `lnfj' `d11' = `h11', eq(1);
		mlmatsum `lnfj' `d12' = `h12', eq(1,2);
		mlmatsum `lnfj' `d13' = `h13', eq(1,3);
		mlmatsum `lnfj' `d22' = `h22', eq(2);
		mlmatsum `lnfj' `d23' = `h23', eq(2,3);
		mlmatsum `lnfj' `d33' = `h33', eq(3);
		matrix `H' = (`d11',`d12',`d13' \ `d12'',`d22',`d23' \ `d13'',`d23'',`d33');
	};
end;

program HAS_Heckprobit1_lf2;
	version 16.1;
	args todo b lnfj g1 g2 g3 g4 g5 H;
	tempvar z1 z2 q1 q2 w1 w2 rhos delta v1 v2 ge1 ge2 bden qf cc A;
	tempname ihtrho eta0 eta1 alp0 alp1;
	mleval `z1' = `b', eq(1);
	mleval `z2' = `b', eq(2);
	mleval `ihtrho' = `b', eq(3) scalar;
	mleval `eta0' = `b', eq(4) scalar;
	mleval `eta1' = `b', eq(5) scalar;
	quietly {;
		generate double `q1' = (2*$ML_y1) - 1;
		generate double `q2' = (2*$ML_y2) - 1;
		generate double `w1' = `q1'*`z1';
		generate double `w2' = `q2'*`z2';
		generate double `rhos' = `q1'*`q2'*tanh(`ihtrho');
		generate double `delta' = 1/sqrt(1-(`rhos'^2));
		generate double `v1' = `delta'*(`w2'-(`rhos'*`w1'));
		generate double `v2' = `delta'*(`w1'-(`rhos'*`w2'));
		generate double `ge1' = normalden(`w1')*normal(`v1');
		generate double `ge2' = normalden(`w2')*normal(`v2');
		generate double `bden' = normalden(`w2')*normalden(`v2')*`delta';
		generate double `qf' = (`delta'^2)*`rhos'*(1-((`delta'^2)*((`w1'^2)+(`w2'^2)-(2*`rhos'*`w1'*`w2'))));
		scalar `alp0' = exp(`eta0')/(1+exp(`eta0')+exp(`eta1'));
		scalar `alp1' = exp(`eta1')/(1+exp(`eta0')+exp(`eta1'));
		generate double `cc' = (`alp0'*$ML_y1) + (`alp1'*(1-$ML_y1));
		generate double `A' = ((1-`alp0'-`alp1')*binormal(`w1',`w2',`rhos'))+(`cc'*normal(`w2'));
		replace `lnfj' = ln(`A') if $ML_y2 == 1;
		replace `lnfj' = ln(normal(`w2')) if $ML_y2 ==0;
		if (`todo'==0) exit;
		replace `g1' = (1-`alp0'-`alp1')*`q1'*`ge1'/`A' if $ML_y2 == 1;
		replace `g1' = 0 if $ML_y2 == 0;
		replace `g2' = `q2'*(((1-`alp0'-`alp1')*`ge2')+(`cc'*normalden(`w2')))/`A' if $ML_y2 == 1;
		replace `g2' = `q2'*normalden(`w2')/normal(`w2') if $ML_y2 == 0;
		replace `g3' = ((1-`alp0'-`alp1')*`q1'*`q2'*`bden'/`A')*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `g3' = 0 if $ML_y2 == 0;
		replace `g4' = `alp0'*((normal(`w2')*$ML_y1)-`A')/`A' if $ML_y2 == 1;
		replace `g4' = 0 if $ML_y2 == 0;
		replace `g5' = `alp1'*((normal(`w2')*(1-$ML_y1))-`A')/`A' if $ML_y2 == 1;
		replace `g5' = 0 if $ML_y2 == 0;
		if (`todo'==1) exit;
		tempvar h11 h12 h13 h14 h15 h22 h23 h24 h25 h33 h34 h35 h44 h45 h55;
		gen double `h11' = -(1-`alp0'-`alp1')*((`w1'*`ge1'/`A')+(`rhos'*`bden'/`A')+((1-`alp0'-`alp1')*((`ge1'/`A')^2))) if $ML_y2 == 1;
		replace `h11' = 0 if $ML_y2 == 0;
		gen double `h12' = (1-`alp0'-`alp1')*`q1'*`q2'*((`bden'/`A')-((1-`alp0'-`alp1')*`ge1'*`ge2'/(`A'^2))-(`cc'*normalden(`w2')*`ge1'/(`A'^2))) if $ML_y2 == 1;
		replace `h12' = 0 if $ML_y2 == 0;
		gen double `h13' = ((1-`alp0'-`alp1')*`q2'*`bden'*((`rhos'*`delta'*`v1')-`w1'-((1-`alp0'-`alp1')*`ge1'/`A'))/`A')*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `h13' = 0 if $ML_y2 == 0;
		gen double `h14' = -`alp0'*(1-`alp0'-`alp1')*`q1'*`ge1'*$ML_y1*normal(`w2')/(`A'^2) if $ML_y2 == 1;
		replace `h14' = 0 if $ML_y2 == 0;
		gen double `h15' = -`alp1'*(1-`alp0'-`alp1')*`q1'*`ge1'*(1-$ML_y1)*normal(`w2')/(`A'^2) if $ML_y2 == 1;
		replace `h15' = 0 if $ML_y2 == 0;
		gen double `h22' = -((1-`alp0'-`alp1')*`w2'*`ge2'/`A')-((1-`alp0'-`alp1')*`rhos'*`bden'/`A')-(`cc'*`w2'*normalden(`w2')/`A')-(((((1-`alp0'-`alp1')*`ge2')+(`cc'*normalden(`w2')))/`A')^2) if $ML_y2 == 1;
		replace `h22' = -normalden(`w2')*(`w2'+(normalden(`w2')/normal(`w2')))/normal(`w2') if $ML_y2 == 0;
		gen double `h23' = ((1-`alp0'-`alp1')*`q1'*`bden'*((`rhos'*`delta'*`v2')-`w2'-((((1-`alp0'-`alp1')*`ge2')+(`cc'*normalden(`w2')))/`A'))/`A')*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `h23' = 0 if $ML_y2 == 0;
		gen double `h24' = -`alp0'*`q2'*$ML_y1*(((1-`alp0'-`alp1')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp0'*normal(`w2'))-`A')))/(`A'^2) if $ML_y2 == 1;
		replace `h24' = 0 if $ML_y2 == 0;
		gen double `h25' = -`alp1'*`q2'*(1-$ML_y1)*(((1-`alp0'-`alp1')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp1'*normal(`w2'))-`A')))/(`A'^2) if $ML_y2 == 1;
		replace `h25' = 0 if $ML_y2 == 0;
		gen double `h33' = ((((1-`alp0'-`alp1')*`bden'*(`qf'+((`delta'^2)*`w1'*`w2')-((1-`alp0'-`alp1')*`bden'/`A'))/`A')*(1-(tanh(`ihtrho')^2)))-(2*tanh(`ihtrho')*((1-`alp0'-`alp1')*`q1'*`q2'*`bden'/`A')))*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `h33' = 0 if $ML_y2 == 0;
		gen double `h34' = -`alp0'*(1-`alp0'-`alp1')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*$ML_y1*normal(`w2')/(`A'^2) if $ML_y2 == 1;
		replace `h34' = 0 if $ML_y2 == 0;
		gen double `h35' = -`alp1'*(1-`alp0'-`alp1')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*(1-$ML_y1)*normal(`w2')/(`A'^2) if $ML_y2 == 1;
		replace `h35' = 0 if $ML_y2 == 0;
		gen double `h44' = `alp0'*(($ML_y1*normal(`w2'))-`A')*(1-(2*`alp0')-(`alp0'*(($ML_y1*normal(`w2'))-`A')/`A'))/`A' if $ML_y2 == 1;
		replace `h44' = 0 if $ML_y2 == 0;
		gen double `h45' = `alp0'*`alp1' if $ML_y2 == 1;
		replace `h45' = 0 if $ML_y2 == 0;
		gen double `h55' = `alp1'*(((1-$ML_y1)*normal(`w2'))-`A')*(1-(2*`alp1')-(`alp1'*(((1-$ML_y1)*normal(`w2'))-`A')/`A'))/`A' if $ML_y2 == 1;
		replace `h55' = 0 if $ML_y2 == 0;
		tempname d11 d12 d13 d14 d15 d22 d23 d24 d25 d33 d34 d35 d44 d45 d55;
		mlmatsum `lnfj' `d11' = `h11', eq(1);
		mlmatsum `lnfj' `d12' = `h12', eq(1,2);
		mlmatsum `lnfj' `d13' = `h13', eq(1,3);
		mlmatsum `lnfj' `d14' = `h14', eq(1,4);
		mlmatsum `lnfj' `d15' = `h15', eq(1,5);
		mlmatsum `lnfj' `d22' = `h22', eq(2);
		mlmatsum `lnfj' `d23' = `h23', eq(2,3);
		mlmatsum `lnfj' `d24' = `h24', eq(2,4);
		mlmatsum `lnfj' `d25' = `h25', eq(2,5);
		mlmatsum `lnfj' `d33' = `h33', eq(3);
		mlmatsum `lnfj' `d34' = `h34', eq(3,4);
		mlmatsum `lnfj' `d35' = `h35', eq(3,5);
		mlmatsum `lnfj' `d44' = `h44', eq(4);
		mlmatsum `lnfj' `d45' = `h45', eq(4,5);
		mlmatsum `lnfj' `d55' = `h55', eq(5);
		matrix `H' = (`d11',`d12',`d13',`d14',`d15' \ `d12'',`d22',`d23',`d24',`d25' \ `d13'',`d23'',`d33',`d34',`d35' \ `d14'',`d24'',`d34'',`d44',`d45' \ `d15'',`d25'',`d35'',`d45'',`d55');
	};
end;

program HAS_Heckprobit2_lf;
	version 16.1;
	args lnfj z1 z2 ihtrho eta0_11 eta1_11 eta0_12 eta1_12 eta0_21 eta1_21 eta0_22 eta1_22;
	tempvar q1 q2 w1 w2 rhos alp0 alp1 cc A;
	tempname alp0_11 alp1_11 alp0_12 alp1_12 alp0_21 alp1_21 alp0_22 alp1_22;
	quietly {;
		generate double `q1' = (2*$ML_y1) - 1;
		generate double `q2' = (2*$ML_y2) - 1;
		generate double `w1' = `q1'*`z1';
		generate double `w2' = `q2'*`z2';
		generate double `rhos' = `q1'*`q2'*tanh(`ihtrho');
		scalar `alp0_11' = exp(`eta0_11')/(1+exp(`eta0_11')+exp(`eta1_11'));
		scalar `alp1_11' = exp(`eta1_11')/(1+exp(`eta0_11')+exp(`eta1_11'));
		scalar `alp0_12' = exp(`eta0_12')/(1+exp(`eta0_12')+exp(`eta1_12'));
		scalar `alp1_12' = exp(`eta1_12')/(1+exp(`eta0_12')+exp(`eta1_12'));
		scalar `alp0_21' = exp(`eta0_21')/(1+exp(`eta0_21')+exp(`eta1_21'));
		scalar `alp1_21' = exp(`eta1_21')/(1+exp(`eta0_21')+exp(`eta1_21'));
		scalar `alp0_22' = exp(`eta0_22')/(1+exp(`eta0_22')+exp(`eta1_22'));
		scalar `alp1_22' = exp(`eta1_22')/(1+exp(`eta0_22')+exp(`eta1_22'));
		generate double `alp0' = (`alp0_11'*x11d*(1-x12))+(`alp0_12'*x11d*x12)+(`alp0_21'*(1-x11d)*(1-x12))+(`alp0_22'*(1-x11d)*x12);
		generate double `alp1' = (`alp1_11'*x11d*(1-x12))+(`alp1_12'*x11d*x12)+(`alp1_21'*(1-x11d)*(1-x12))+(`alp1_22'*(1-x11d)*x12);
		generate double `cc' = (`alp0'*$ML_y1) + (`alp1'*(1-$ML_y1));
		generate double `A' = ((1-`alp0'-`alp1')*binormal(`w1',`w2',`rhos'))+(`cc'*normal(`w2'));
		replace `lnfj' = ln(`A') if $ML_y2 == 1;
		replace `lnfj' = ln(normal(`w2')) if $ML_y2 == 0;
	};
end;
		
program HAS_Heckprobit2_lf2;
	version 16.1;
	args todo b lnfj g1 g2 g3 g4 g5 g6 g7 g8 g9 g10 g11 H;
	tempvar z1 z2 q1 q2 w1 w2 rhos delta v1 v2 ge1 ge2 bden qf cc_11 cc_12 cc_21 cc_22 A_11 A_12 A_21 A_22;
	tempname ihtrho eta0_11 eta1_11 eta0_12 eta1_12 eta0_21 eta1_21 eta0_22 eta1_22 alp0_11 alp1_11 alp0_12 alp1_12 alp0_21 alp1_21 alp0_22 alp1_22;
	mleval `z1' = `b', eq(1);
	mleval `z2' = `b', eq(2);
	mleval `ihtrho' = `b', eq(3) scalar;
	mleval `eta0_11' = `b', eq(4) scalar;
	mleval `eta1_11' = `b', eq(5) scalar;
	mleval `eta0_12' = `b', eq(6) scalar;
	mleval `eta1_12' = `b', eq(7) scalar;
	mleval `eta0_21' = `b', eq(8) scalar;
	mleval `eta1_21' = `b', eq(9) scalar;
	mleval `eta0_22' = `b', eq(10) scalar;
	mleval `eta1_22' = `b', eq(11) scalar;
	quietly {;
		generate double `q1' = (2*$ML_y1) - 1;
		generate double `q2' = (2*$ML_y2) - 1;
		generate double `w1' = `q1'*`z1';
		generate double `w2' = `q2'*`z2';
		generate double `rhos' = `q1'*`q2'*tanh(`ihtrho');
		generate double `delta' = 1/sqrt(1-(`rhos'^2));
		generate double `v1' = `delta'*(`w2'-(`rhos'*`w1'));
		generate double `v2' = `delta'*(`w1'-(`rhos'*`w2'));
		generate double `ge1' = normalden(`w1')*normal(`v1');
		generate double `ge2' = normalden(`w2')*normal(`v2');
		generate double `bden' = normalden(`w2')*normalden(`v2')*`delta';
		generate double `qf' = (`delta'^2)*`rhos'*(1-((`delta'^2)*((`w1'^2)+(`w2'^2)-(2*`rhos'*`w1'*`w2'))));
		scalar `alp0_11' = exp(`eta0_11')/(1+exp(`eta0_11')+exp(`eta1_11'));
		scalar `alp1_11' = exp(`eta1_11')/(1+exp(`eta0_11')+exp(`eta1_11'));
		scalar `alp0_12' = exp(`eta0_12')/(1+exp(`eta0_12')+exp(`eta1_12'));
		scalar `alp1_12' = exp(`eta1_12')/(1+exp(`eta0_12')+exp(`eta1_12'));
		scalar `alp0_21' = exp(`eta0_21')/(1+exp(`eta0_21')+exp(`eta1_21'));
		scalar `alp1_21' = exp(`eta1_21')/(1+exp(`eta0_21')+exp(`eta1_21'));
		scalar `alp0_22' = exp(`eta0_22')/(1+exp(`eta0_22')+exp(`eta1_22'));
		scalar `alp1_22' = exp(`eta1_22')/(1+exp(`eta0_22')+exp(`eta1_22'));
		generate double `cc_11' = (`alp0_11'*$ML_y1) + (`alp1_11'*(1-$ML_y1));
		generate double `cc_12' = (`alp0_12'*$ML_y1) + (`alp1_12'*(1-$ML_y1));
		generate double `cc_21' = (`alp0_21'*$ML_y1) + (`alp1_21'*(1-$ML_y1));
		generate double `cc_22' = (`alp0_22'*$ML_y1) + (`alp1_22'*(1-$ML_y1));
		generate double `A_11' = ((1-`alp0_11'-`alp1_11')*binormal(`w1',`w2',`rhos'))+(`cc_11'*normal(`w2'));
		generate double `A_12' = ((1-`alp0_12'-`alp1_12')*binormal(`w1',`w2',`rhos'))+(`cc_12'*normal(`w2'));
		generate double `A_21' = ((1-`alp0_21'-`alp1_21')*binormal(`w1',`w2',`rhos'))+(`cc_21'*normal(`w2'));
		generate double `A_22' = ((1-`alp0_22'-`alp1_22')*binormal(`w1',`w2',`rhos'))+(`cc_22'*normal(`w2'));
		replace `lnfj' = ln(`A_11') if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `lnfj' = ln(`A_12') if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `lnfj' = ln(`A_21') if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `lnfj' = ln(`A_22') if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `lnfj' = ln(normal(`w2')) if $ML_y2 == 0;
		if (`todo'==0) exit;
		replace `g1' = (1-`alp0_11'-`alp1_11')*`q1'*`ge1'/`A_11' if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g1' = (1-`alp0_12'-`alp1_12')*`q1'*`ge1'/`A_12' if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g1' = (1-`alp0_21'-`alp1_21')*`q1'*`ge1'/`A_21' if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g1' = (1-`alp0_22'-`alp1_22')*`q1'*`ge1'/`A_22' if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g1' = 0 if $ML_y2 == 0;
		replace `g2' = `q2'*(((1-`alp0_11'-`alp1_11')*`ge2')+(`cc_11'*normalden(`w2')))/`A_11' if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g2' = `q2'*(((1-`alp0_12'-`alp1_12')*`ge2')+(`cc_12'*normalden(`w2')))/`A_12' if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g2' = `q2'*(((1-`alp0_21'-`alp1_21')*`ge2')+(`cc_21'*normalden(`w2')))/`A_21' if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g2' = `q2'*(((1-`alp0_22'-`alp1_22')*`ge2')+(`cc_22'*normalden(`w2')))/`A_22' if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g2' = `q2'*normalden(`w2')/normal(`w2') if $ML_y2 == 0;
		replace `g3' = ((1-`alp0_11'-`alp1_11')*`q1'*`q2'*`bden'/`A_11')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g3' = ((1-`alp0_12'-`alp1_12')*`q1'*`q2'*`bden'/`A_12')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g3' = ((1-`alp0_21'-`alp1_21')*`q1'*`q2'*`bden'/`A_21')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g3' = ((1-`alp0_22'-`alp1_22')*`q1'*`q2'*`bden'/`A_22')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g3' = 0 if $ML_y2 == 0;
		replace `g4' = `alp0_11'*((normal(`w2')*$ML_y1)-`A_11')/`A_11' if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g4' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g4' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g4' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g4' = 0 if $ML_y2 == 0;
		replace `g5' = `alp1_11'*((normal(`w2')*(1-$ML_y1))-`A_11')/`A_11' if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g5' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g5' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g5' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g5' = 0 if $ML_y2 == 0;
		replace `g6' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g6' = `alp0_12'*((normal(`w2')*$ML_y1)-`A_12')/`A_12' if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g6' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g6' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g6' = 0 if $ML_y2 == 0;
		replace `g7' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g7' = `alp1_12'*((normal(`w2')*(1-$ML_y1))-`A_12')/`A_12' if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g7' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g7' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g7' = 0 if $ML_y2 == 0;
		replace `g8' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g8' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g8' = `alp0_21'*((normal(`w2')*$ML_y1)-`A_21')/`A_21' if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g8' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g8' = 0 if $ML_y2 == 0;
		replace `g9' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g9' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g9' = `alp1_21'*((normal(`w2')*(1-$ML_y1))-`A_21')/`A_21' if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g9' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g9' = 0 if $ML_y2 == 0;
		replace `g10' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g10' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g10' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g10' = `alp0_22'*((normal(`w2')*$ML_y1)-`A_22')/`A_22' if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g10' = 0 if $ML_y2 == 0;
		replace `g11' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `g11' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `g11' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `g11' = `alp1_22'*((normal(`w2')*(1-$ML_y1))-`A_22')/`A_22' if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `g11' = 0 if $ML_y2 == 0;
		if (`todo'==1) exit;
		tempvar h11 h12 h13 h14 h15 h16 h17 h18 h19 h110 h111 h22 h23 h24 h25 h26 h27 h28 h29 h210 h211 h33 h34 h35 h36 h37 h38 h39 h310 h311 h44 h45 h46 h47 h48 h49 h410 h411 h55 h56 h57 h58 h59 h510 h511 h66 h67 h68 h69 h610 h611 h77 h78 h79 h710 h711 h88 h89 h810 h811 h99 h910 h911 h1010 h1011 h1111;
		gen double `h11' = -(1-`alp0_11'-`alp1_11')*((`w1'*`ge1'/`A_11')+(`rhos'*`bden'/`A_11')+((1-`alp0_11'-`alp1_11')*((`ge1'/`A_11')^2))) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h11' = -(1-`alp0_12'-`alp1_12')*((`w1'*`ge1'/`A_12')+(`rhos'*`bden'/`A_12')+((1-`alp0_12'-`alp1_12')*((`ge1'/`A_12')^2))) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h11' = -(1-`alp0_21'-`alp1_21')*((`w1'*`ge1'/`A_21')+(`rhos'*`bden'/`A_21')+((1-`alp0_21'-`alp1_21')*((`ge1'/`A_21')^2))) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h11' = -(1-`alp0_22'-`alp1_22')*((`w1'*`ge1'/`A_22')+(`rhos'*`bden'/`A_22')+((1-`alp0_22'-`alp1_22')*((`ge1'/`A_22')^2))) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h11' = 0 if $ML_y2 == 0;
		gen double `h12' = (1-`alp0_11'-`alp1_11')*`q1'*`q2'*((`bden'/`A_11')-((1-`alp0_11'-`alp1_11')*`ge1'*`ge2'/(`A_11'^2))-(`cc_11'*normalden(`w2')*`ge1'/(`A_11'^2))) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h12' = (1-`alp0_12'-`alp1_12')*`q1'*`q2'*((`bden'/`A_12')-((1-`alp0_12'-`alp1_12')*`ge1'*`ge2'/(`A_12'^2))-(`cc_12'*normalden(`w2')*`ge1'/(`A_12'^2))) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h12' = (1-`alp0_21'-`alp1_21')*`q1'*`q2'*((`bden'/`A_21')-((1-`alp0_21'-`alp1_21')*`ge1'*`ge2'/(`A_21'^2))-(`cc_21'*normalden(`w2')*`ge1'/(`A_21'^2))) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h12' = (1-`alp0_22'-`alp1_22')*`q1'*`q2'*((`bden'/`A_22')-((1-`alp0_22'-`alp1_22')*`ge1'*`ge2'/(`A_22'^2))-(`cc_22'*normalden(`w2')*`ge1'/(`A_22'^2))) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h12' = 0 if $ML_y2 == 0;
		gen double `h13' = ((1-`alp0_11'-`alp1_11')*`q2'*`bden'*((`rhos'*`delta'*`v1')-`w1'-((1-`alp0_11'-`alp1_11')*`ge1'/`A_11'))/`A_11')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h13' = ((1-`alp0_12'-`alp1_12')*`q2'*`bden'*((`rhos'*`delta'*`v1')-`w1'-((1-`alp0_12'-`alp1_12')*`ge1'/`A_12'))/`A_12')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h13' = ((1-`alp0_21'-`alp1_21')*`q2'*`bden'*((`rhos'*`delta'*`v1')-`w1'-((1-`alp0_21'-`alp1_21')*`ge1'/`A_21'))/`A_21')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h13' = ((1-`alp0_22'-`alp1_22')*`q2'*`bden'*((`rhos'*`delta'*`v1')-`w1'-((1-`alp0_22'-`alp1_22')*`ge1'/`A_22'))/`A_22')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h13' = 0 if $ML_y2 == 0;
		gen double `h14' = -`alp0_11'*(1-`alp0_11'-`alp1_11')*`q1'*`ge1'*$ML_y1*normal(`w2')/(`A_11'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h14' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h14' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h14' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h14' = 0 if $ML_y2 == 0;
		gen double `h15' = -`alp1_11'*(1-`alp0_11'-`alp1_11')*`q1'*`ge1'*(1-$ML_y1)*normal(`w2')/(`A_11'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h15' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h15' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h15' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h15' = 0 if $ML_y2 == 0;
		gen double `h16' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h16' = -`alp0_12'*(1-`alp0_12'-`alp1_12')*`q1'*`ge1'*$ML_y1*normal(`w2')/(`A_12'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h16' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h16' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h16' = 0 if $ML_y2 == 0;
		gen double `h17' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h17' = -`alp1_12'*(1-`alp0_12'-`alp1_12')*`q1'*`ge1'*(1-$ML_y1)*normal(`w2')/(`A_12'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h17' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h17' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h17' = 0 if $ML_y2 == 0;
		gen double `h18' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h18' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h18' = -`alp0_21'*(1-`alp0_21'-`alp1_21')*`q1'*`ge1'*$ML_y1*normal(`w2')/(`A_21'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h18' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h18' = 0 if $ML_y2 == 0;
		gen double `h19' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h19' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h19' = -`alp1_21'*(1-`alp0_21'-`alp1_21')*`q1'*`ge1'*(1-$ML_y1)*normal(`w2')/(`A_21'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h19' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h19' = 0 if $ML_y2 == 0;
		gen double `h110' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h110' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h110' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h110' = -`alp0_22'*(1-`alp0_22'-`alp1_22')*`q1'*`ge1'*$ML_y1*normal(`w2')/(`A_22'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h110' = 0 if $ML_y2 == 0;
		gen double `h111' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h111' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h111' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h111' = -`alp1_22'*(1-`alp0_22'-`alp1_22')*`q1'*`ge1'*(1-$ML_y1)*normal(`w2')/(`A_22'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h111' = 0 if $ML_y2 == 0;
		gen double `h22' = -((1-`alp0_11'-`alp1_11')*`w2'*`ge2'/`A_11')-((1-`alp0_11'-`alp1_11')*`rhos'*`bden'/`A_11')-(`cc_11'*`w2'*normalden(`w2')/`A_11')-(((((1-`alp0_11'-`alp1_11')*`ge2')+(`cc_11'*normalden(`w2')))/`A_11')^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h22' = -((1-`alp0_12'-`alp1_12')*`w2'*`ge2'/`A_12')-((1-`alp0_12'-`alp1_12')*`rhos'*`bden'/`A_12')-(`cc_12'*`w2'*normalden(`w2')/`A_12')-(((((1-`alp0_12'-`alp1_12')*`ge2')+(`cc_12'*normalden(`w2')))/`A_12')^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h22' = -((1-`alp0_21'-`alp1_21')*`w2'*`ge2'/`A_21')-((1-`alp0_21'-`alp1_21')*`rhos'*`bden'/`A_21')-(`cc_21'*`w2'*normalden(`w2')/`A_21')-(((((1-`alp0_21'-`alp1_21')*`ge2')+(`cc_21'*normalden(`w2')))/`A_21')^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h22' = -((1-`alp0_22'-`alp1_22')*`w2'*`ge2'/`A_22')-((1-`alp0_22'-`alp1_22')*`rhos'*`bden'/`A_22')-(`cc_22'*`w2'*normalden(`w2')/`A_22')-(((((1-`alp0_22'-`alp1_22')*`ge2')+(`cc_22'*normalden(`w2')))/`A_22')^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h22' = -normalden(`w2')*(`w2'+(normalden(`w2')/normal(`w2')))/normal(`w2') if $ML_y2 == 0;
		gen double `h23' = ((1-`alp0_11'-`alp1_11')*`q1'*`bden'*((`rhos'*`delta'*`v2')-`w2'-((((1-`alp0_11'-`alp1_11')*`ge2')+(`cc_11'*normalden(`w2')))/`A_11'))/`A_11')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h23' = ((1-`alp0_12'-`alp1_12')*`q1'*`bden'*((`rhos'*`delta'*`v2')-`w2'-((((1-`alp0_12'-`alp1_12')*`ge2')+(`cc_12'*normalden(`w2')))/`A_12'))/`A_12')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h23' = ((1-`alp0_21'-`alp1_21')*`q1'*`bden'*((`rhos'*`delta'*`v2')-`w2'-((((1-`alp0_21'-`alp1_21')*`ge2')+(`cc_21'*normalden(`w2')))/`A_21'))/`A_21')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h23' = ((1-`alp0_22'-`alp1_22')*`q1'*`bden'*((`rhos'*`delta'*`v2')-`w2'-((((1-`alp0_22'-`alp1_22')*`ge2')+(`cc_22'*normalden(`w2')))/`A_22'))/`A_22')*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h23' = 0 if $ML_y2 == 0;
		gen double `h24' = -`alp0_11'*`q2'*$ML_y1*(((1-`alp0_11'-`alp1_11')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp0_11'*normal(`w2'))-`A_11')))/(`A_11'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h24' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h24' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h24' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h24' = 0 if $ML_y2 == 0;
		gen double `h25' = -`alp1_11'*`q2'*(1-$ML_y1)*(((1-`alp0_11'-`alp1_11')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp1_11'*normal(`w2'))-`A_11')))/(`A_11'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h25' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h25' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h25' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h25' = 0 if $ML_y2 == 0;
		gen double `h26' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h26' = -`alp0_12'*`q2'*$ML_y1*(((1-`alp0_12'-`alp1_12')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp0_12'*normal(`w2'))-`A_12')))/(`A_12'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h26' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h26' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h26' = 0 if $ML_y2 == 0;
		gen double `h27' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h27' = -`alp1_12'*`q2'*(1-$ML_y1)*(((1-`alp0_12'-`alp1_12')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp1_12'*normal(`w2'))-`A_12')))/(`A_12'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h27' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h27' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h27' = 0 if $ML_y2 == 0;
		gen double `h28' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h28' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h28' = -`alp0_21'*`q2'*$ML_y1*(((1-`alp0_21'-`alp1_21')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp0_21'*normal(`w2'))-`A_21')))/(`A_21'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h28' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h28' = 0 if $ML_y2 == 0;
		gen double `h29' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h29' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h29' = -`alp1_21'*`q2'*(1-$ML_y1)*(((1-`alp0_21'-`alp1_21')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp1_21'*normal(`w2'))-`A_21')))/(`A_21'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h29' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h29' = 0 if $ML_y2 == 0;
		gen double `h210' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h210' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h210' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h210' = -`alp0_22'*`q2'*$ML_y1*(((1-`alp0_22'-`alp1_22')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp0_22'*normal(`w2'))-`A_22')))/(`A_22'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h210' = 0 if $ML_y2 == 0;
		gen double `h211' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h211' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h211' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h211' = -`alp1_22'*`q2'*(1-$ML_y1)*(((1-`alp0_22'-`alp1_22')*`ge2'*normal(`w2'))+(normalden(`w2')*((`alp1_22'*normal(`w2'))-`A_22')))/(`A_22'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h211' = 0 if $ML_y2 == 0;
		gen double `h33' = ((((1-`alp0_11'-`alp1_11')*`bden'*(`qf'+((`delta'^2)*`w1'*`w2')-((1-`alp0_11'-`alp1_11')*`bden'/`A_11'))/`A_11')*(1-(tanh(`ihtrho')^2)))-(2*tanh(`ihtrho')*((1-`alp0_11'-`alp1_11')*`q1'*`q2'*`bden'/`A_11')))*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h33' = ((((1-`alp0_12'-`alp1_12')*`bden'*(`qf'+((`delta'^2)*`w1'*`w2')-((1-`alp0_12'-`alp1_12')*`bden'/`A_12'))/`A_12')*(1-(tanh(`ihtrho')^2)))-(2*tanh(`ihtrho')*((1-`alp0_12'-`alp1_12')*`q1'*`q2'*`bden'/`A_12')))*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h33' = ((((1-`alp0_21'-`alp1_21')*`bden'*(`qf'+((`delta'^2)*`w1'*`w2')-((1-`alp0_21'-`alp1_21')*`bden'/`A_21'))/`A_21')*(1-(tanh(`ihtrho')^2)))-(2*tanh(`ihtrho')*((1-`alp0_21'-`alp1_21')*`q1'*`q2'*`bden'/`A_21')))*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h33' = ((((1-`alp0_22'-`alp1_22')*`bden'*(`qf'+((`delta'^2)*`w1'*`w2')-((1-`alp0_22'-`alp1_22')*`bden'/`A_22'))/`A_22')*(1-(tanh(`ihtrho')^2)))-(2*tanh(`ihtrho')*((1-`alp0_22'-`alp1_22')*`q1'*`q2'*`bden'/`A_22')))*(1-(tanh(`ihtrho')^2)) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h33' = 0 if $ML_y2 == 0;
		gen double `h34' = -`alp0_11'*(1-`alp0_11'-`alp1_11')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*$ML_y1*normal(`w2')/(`A_11'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h34' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h34' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h34' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h34' = 0 if $ML_y2 == 0;
		gen double `h35' = -`alp1_11'*(1-`alp0_11'-`alp1_11')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*(1-$ML_y1)*normal(`w2')/(`A_11'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h35' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h35' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h35' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h35' = 0 if $ML_y2 == 0;
		gen double `h36' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h36' = -`alp0_12'*(1-`alp0_12'-`alp1_12')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*$ML_y1*normal(`w2')/(`A_12'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h36' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h36' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h36' = 0 if $ML_y2 == 0;
		gen double `h37' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h37' = -`alp1_12'*(1-`alp0_12'-`alp1_12')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*(1-$ML_y1)*normal(`w2')/(`A_12'^2) if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h37' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h37' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h37' = 0 if $ML_y2 == 0;
		gen double `h38' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h38' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h38' = -`alp0_21'*(1-`alp0_21'-`alp1_21')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*$ML_y1*normal(`w2')/(`A_21'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h38' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h38' = 0 if $ML_y2 == 0;
		gen double `h39' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h39' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h39' = -`alp1_21'*(1-`alp0_21'-`alp1_21')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*(1-$ML_y1)*normal(`w2')/(`A_21'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h39' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h39' = 0 if $ML_y2 == 0;
		gen double `h310' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h310' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h310' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h310' = -`alp0_22'*(1-`alp0_22'-`alp1_22')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*$ML_y1*normal(`w2')/(`A_22'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h310' = 0 if $ML_y2 == 0;
		gen double `h311' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h311' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h311' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h311' = -`alp1_22'*(1-`alp0_22'-`alp1_22')*`q1'*`q2'*`bden'*(1-(tanh(`ihtrho')^2))*(1-$ML_y1)*normal(`w2')/(`A_22'^2) if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h311' = 0 if $ML_y2 == 0;
		gen double `h44' = `alp0_11'*(($ML_y1*normal(`w2'))-`A_11')*(1-(2*`alp0_11')-(`alp0_11'*(($ML_y1*normal(`w2'))-`A_11')/`A_11'))/`A_11' if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h44' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h44' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h44' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h44' = 0 if $ML_y2 == 0;
		gen double `h45' = `alp0_11'*`alp1_11' if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h45' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h45' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h45' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h45' = 0 if $ML_y2 == 0;
		gen double `h46' = 0;
		gen double `h47' = 0;
		gen double `h48' = 0;
		gen double `h49' = 0;
		gen double `h410' = 0;
		gen double `h411' = 0;
		gen double `h55' = `alp1_11'*(((1-$ML_y1)*normal(`w2'))-`A_11')*(1-(2*`alp1_11')-(`alp1_11'*(((1-$ML_y1)*normal(`w2'))-`A_11')/`A_11'))/`A_11' if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h55' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h55' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h55' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h55' = 0 if $ML_y2 == 0;
		gen double `h56' = 0;
		gen double `h57' = 0;
		gen double `h58' = 0;
		gen double `h59' = 0;
		gen double `h510' = 0;
		gen double `h511' = 0;
		gen double `h66' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h66' = `alp0_12'*(($ML_y1*normal(`w2'))-`A_12')*(1-(2*`alp0_12')-(`alp0_12'*(($ML_y1*normal(`w2'))-`A_12')/`A_12'))/`A_12' if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h66' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h66' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h66' = 0 if $ML_y2 == 0;
		gen double `h67' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h67' = `alp0_12'*`alp1_12' if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h67' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h67' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h67' = 0 if $ML_y2 == 0;
		gen double `h68' = 0;
		gen double `h69' = 0;
		gen double `h610' = 0;
		gen double `h611' = 0;
		gen double `h77' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h77' = `alp1_12'*(((1-$ML_y1)*normal(`w2'))-`A_12')*(1-(2*`alp1_12')-(`alp1_12'*(((1-$ML_y1)*normal(`w2'))-`A_12')/`A_12'))/`A_12' if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h77' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h77' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h77' = 0 if $ML_y2 == 0;
		gen double `h78' = 0;
		gen double `h79' = 0;
		gen double `h710' = 0;
		gen double `h711' = 0;
		gen double `h88' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h88' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h88' = `alp0_21'*(($ML_y1*normal(`w2'))-`A_21')*(1-(2*`alp0_21')-(`alp0_21'*(($ML_y1*normal(`w2'))-`A_21')/`A_21'))/`A_21' if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h88' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h88' = 0 if $ML_y2 == 0;
		gen double `h89' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h89' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h89' = `alp0_21'*`alp1_21' if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h89' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h89' = 0 if $ML_y2 == 0;
		gen double `h810' = 0;
		gen double `h811' = 0;
		gen double `h99' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h99' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h99' = `alp1_21'*(((1-$ML_y1)*normal(`w2'))-`A_21')*(1-(2*`alp1_21')-(`alp1_21'*(((1-$ML_y1)*normal(`w2'))-`A_21')/`A_21'))/`A_21' if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h99' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h99' = 0 if $ML_y2 == 0;
		gen double `h910' = 0;
		gen double `h911' = 0;
		gen double `h1010' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h1010' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h1010' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h1010' = `alp0_22'*(($ML_y1*normal(`w2'))-`A_22')*(1-(2*`alp0_22')-(`alp0_22'*(($ML_y1*normal(`w2'))-`A_22')/`A_22'))/`A_22' if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h1010' = 0 if $ML_y2 == 0;
		gen double `h1011' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h1011' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h1011' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h1011' = `alp0_22'*`alp1_22' if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h1011' = 0 if $ML_y2 == 0;
		gen double `h1111' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 0);
		replace `h1111' = 0 if ($ML_y2 == 1 & x11d == 1 & x12 == 1);
		replace `h1111' = 0 if ($ML_y2 == 1 & x11d == 0 & x12 == 0);
		replace `h1111' = `alp1_22'*(((1-$ML_y1)*normal(`w2'))-`A_22')*(1-(2*`alp1_22')-(`alp1_22'*(((1-$ML_y1)*normal(`w2'))-`A_22')/`A_22'))/`A_22' if ($ML_y2 == 1 & x11d == 0 & x12 == 1);
		replace `h1111' = 0 if $ML_y2 == 0;
		tempname d11 d12 d13 d14 d15 d16 d17 d18 d19 d110 d111 d22 d23 d24 d25 d26 d27 d28 d29 d210 d211 d33 d34 d35 d36 d37 d38 d39 d310 d311 d44 d45 d46 d47 d48 d49 d410 d411 d55 d56 d57 d58 d59 d510 d511 d66 d67 d68 d69 d610 d611 d77 d78 d79 d710 d711 d88 d89 d810 d811 d99 d910 d911 d1010 d1011 d1111;
		mlmatsum `lnfj' `d11' = `h11', eq(1);
		mlmatsum `lnfj' `d12' = `h12', eq(1,2);
		mlmatsum `lnfj' `d13' = `h13', eq(1,3);
		mlmatsum `lnfj' `d14' = `h14', eq(1,4);
		mlmatsum `lnfj' `d15' = `h15', eq(1,5);
		mlmatsum `lnfj' `d16' = `h16', eq(1,6);
		mlmatsum `lnfj' `d17' = `h17', eq(1,7);
		mlmatsum `lnfj' `d18' = `h18', eq(1,8);
		mlmatsum `lnfj' `d19' = `h19', eq(1,9);
		mlmatsum `lnfj' `d110' = `h110', eq(1,10);
		mlmatsum `lnfj' `d111' = `h111', eq(1,11);
		mlmatsum `lnfj' `d22' = `h22', eq(2);
		mlmatsum `lnfj' `d23' = `h23', eq(2,3);
		mlmatsum `lnfj' `d24' = `h24', eq(2,4);
		mlmatsum `lnfj' `d25' = `h25', eq(2,5);
		mlmatsum `lnfj' `d26' = `h26', eq(2,6);
		mlmatsum `lnfj' `d27' = `h27', eq(2,7);
		mlmatsum `lnfj' `d28' = `h28', eq(2,8);
		mlmatsum `lnfj' `d29' = `h29', eq(2,9);
		mlmatsum `lnfj' `d210' = `h210', eq(2,10);
		mlmatsum `lnfj' `d211' = `h211', eq(2,11);
		mlmatsum `lnfj' `d33' = `h33', eq(3);
		mlmatsum `lnfj' `d34' = `h34', eq(3,4);
		mlmatsum `lnfj' `d35' = `h35', eq(3,5);
		mlmatsum `lnfj' `d36' = `h36', eq(3,6);
		mlmatsum `lnfj' `d37' = `h37', eq(3,7);
		mlmatsum `lnfj' `d38' = `h38', eq(3,8);
		mlmatsum `lnfj' `d39' = `h39', eq(3,9);
		mlmatsum `lnfj' `d310' = `h310', eq(3,10);
		mlmatsum `lnfj' `d311' = `h311', eq(3,11);
		mlmatsum `lnfj' `d44' = `h44', eq(4);
		mlmatsum `lnfj' `d45' = `h45', eq(4,5);
		mlmatsum `lnfj' `d46' = `h46', eq(4,6);
		mlmatsum `lnfj' `d47' = `h47', eq(4,7);
		mlmatsum `lnfj' `d48' = `h48', eq(4,8);
		mlmatsum `lnfj' `d49' = `h49', eq(4,9);
		mlmatsum `lnfj' `d410' = `h410', eq(4,10);
		mlmatsum `lnfj' `d411' = `h411', eq(4,11);
		mlmatsum `lnfj' `d55' = `h55', eq(5);
		mlmatsum `lnfj' `d56' = `h56', eq(5,6);
		mlmatsum `lnfj' `d57' = `h57', eq(5,7);
		mlmatsum `lnfj' `d58' = `h58', eq(5,8);
		mlmatsum `lnfj' `d59' = `h59', eq(5,9);
		mlmatsum `lnfj' `d510' = `h510', eq(5,10);
		mlmatsum `lnfj' `d511' = `h511', eq(5,11);
		mlmatsum `lnfj' `d66' = `h66', eq(6);
		mlmatsum `lnfj' `d67' = `h67', eq(6,7);
		mlmatsum `lnfj' `d68' = `h68', eq(6,8);
		mlmatsum `lnfj' `d69' = `h69', eq(6,9);
		mlmatsum `lnfj' `d610' = `h610', eq(6,10);
		mlmatsum `lnfj' `d611' = `h611', eq(6,11);
		mlmatsum `lnfj' `d77' = `h77', eq(7);
		mlmatsum `lnfj' `d78' = `h78', eq(7,8);
		mlmatsum `lnfj' `d79' = `h79', eq(7,9);
		mlmatsum `lnfj' `d710' = `h710', eq(7,10);
		mlmatsum `lnfj' `d711' = `h711', eq(7,11);
		mlmatsum `lnfj' `d88' = `h88', eq(8);
		mlmatsum `lnfj' `d89' = `h89', eq(8,9);
		mlmatsum `lnfj' `d810' = `h810', eq(8,10);
		mlmatsum `lnfj' `d811' = `h811', eq(8,11);
		mlmatsum `lnfj' `d99' = `h99', eq(9);
		mlmatsum `lnfj' `d910' = `h910', eq(9,10);
		mlmatsum `lnfj' `d911' = `h911', eq(9,11);
		mlmatsum `lnfj' `d1010' = `h1010', eq(10);
		mlmatsum `lnfj' `d1011' = `h1011', eq(10,11);
		mlmatsum `lnfj' `d1111' = `h1111', eq(11);
		matrix `H' = (`d11',`d12',`d13',`d14',`d15',`d16',`d17',`d18',`d19',`d110',`d111' \ `d12'',`d22',`d23',`d24',`d25',`d26',`d27',`d28',`d29',`d210',`d211' \ `d13'',`d23'',`d33',`d34',`d35',`d36',`d37',`d38',`d39',`d310',`d311' \ `d14'',`d24'',`d34'',`d44',`d45',`d46',`d47',`d48',`d49',`d410',`d411' \ `d15'',`d25'',`d35'',`d45'',`d55',`d56',`d57',`d58',`d59',`d510',`d511' \ `d16'',`d26'',`d36'',`d46'',`d56'',`d66',`d67',`d68',`d69',`d610',`d611' \ `d17'',`d27'',`d37'',`d47'',`d57'',`d67'',`d77',`d78',`d79',`d710',`d711' \ `d18'',`d28'',`d38'',`d48'',`d58'',`d68'',`d78'',`d88',`d89',`d810',`d811' \ `d19'',`d29'',`d39'',`d49'',`d59'',`d69'',`d79'',`d89'',`d99',`d910',`d911' \ `d110'',`d210'',`d310'',`d410'',`d510'',`d610'',`d710'',`d810'',`d910'',`d1010',`d1011' \ `d111'',`d211'',`d311'',`d411'',`d511'',`d611'',`d711'',`d811'',`d911'',`d1011'',`d1111');
	};
end;

program PP_Probit_lf2;
	version 16.1;
	args todo b lnfj g1 H;
	tempvar xb q lambda A;
	mleval `xb' = `b';
	quietly {;
		generate double `q' = (2*$ML_y1) - 1;
		generate double `A' = (alpha0_i*$ML_y1) + (alpha1_i*(1-$ML_y1)) + (omas_i*normal(`q'*`xb'));
		generate double `lambda' = `q'*omas_i*normalden(`q'*`xb')/`A';
		replace `lnfj' = ln(`A');
		if (`todo'==0) exit;
		replace `g1' = `lambda';
		if (`todo'==1) exit;
		mlmatsum `lnfj' `H' = -`lambda'*(`lambda'+`xb');
	};
end;

program PP_Heckprobit_lf2;
	version 16.1;
	args todo b lnfj g1 g2 g3 H;
	tempvar z1 z2 q1 q2 w1 w2 rhos delta v1 v2 ge1 ge2 bden qf cc A;
	tempname ihtrho;
	mleval `z1' = `b', eq(1);
	mleval `z2' = `b', eq(2);
	mleval `ihtrho' = `b', eq(3) scalar;
	quietly {;
		generate double `q1' = (2*$ML_y1) - 1;
		generate double `q2' = (2*$ML_y2) - 1;
		generate double `w1' = `q1'*`z1';
		generate double `w2' = `q2'*`z2';
		generate double `rhos' = `q1'*`q2'*tanh(`ihtrho');
		generate double `delta' = 1/sqrt(1-(`rhos'^2));
		generate double `v1' = `delta'*(`w2'-(`rhos'*`w1'));
		generate double `v2' = `delta'*(`w1'-(`rhos'*`w2'));
		generate double `ge1' = normalden(`w1')*normal(`v1');
		generate double `ge2' = normalden(`w2')*normal(`v2');
		generate double `bden' = normalden(`w2')*normalden(`v2')*`delta';
		generate double `qf' = (`delta'^2)*`rhos'*(1-((`delta'^2)*((`w1'^2)+(`w2'^2)-(2*`rhos'*`w1'*`w2'))));
		generate double `cc' = (alpha0_i*$ML_y1) + (alpha1_i*(1-$ML_y1));
		generate double `A' = (omas_i*binormal(`w1',`w2',`rhos'))+(`cc'*normal(`w2'));
		replace `lnfj' = ln(`A') if $ML_y2 == 1;
		replace `lnfj' = ln(normal(`w2')) if $ML_y2 ==0;
		if (`todo'==0) exit;
		replace `g1' = omas_i*`q1'*`ge1'/`A' if $ML_y2 == 1;
		replace `g1' = 0 if $ML_y2 == 0;
		replace `g2' = `q2'*((omas_i*`ge2')+(`cc'*normalden(`w2')))/`A' if $ML_y2 == 1;
		replace `g2' = `q2'*normalden(`w2')/normal(`w2') if $ML_y2 == 0;
		replace `g3' = (omas_i*`q1'*`q2'*`bden'/`A')*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `g3' = 0 if $ML_y2 == 0;
		if (`todo'==1) exit;
		tempvar h11 h12 h13 h22 h23 h33;
		gen double `h11' = -omas_i*((`w1'*`ge1'/`A')+(`rhos'*`bden'/`A')+(omas_i*((`ge1'/`A')^2))) if $ML_y2 == 1;
		replace `h11' = 0 if $ML_y2 == 0;
		gen double `h12' = omas_i*`q1'*`q2'*((`bden'/`A')-(omas_i*`ge1'*`ge2'/(`A'^2))-(`cc'*normalden(`w2')*`ge1'/(`A'^2))) if $ML_y2 == 1;
		replace `h12' = 0 if $ML_y2 == 0;
		gen double `h13' = (omas_i*`q2'*`bden'*((`rhos'*`delta'*`v1')-`w1'-(omas_i*`ge1'/`A'))/`A')*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `h13' = 0 if $ML_y2 == 0;
		gen double `h22' = -(omas_i*`w2'*`ge2'/`A')-(omas_i*`rhos'*`bden'/`A')-(`cc'*`w2'*normalden(`w2')/`A')-((((omas_i*`ge2')+(`cc'*normalden(`w2')))/`A')^2) if $ML_y2 == 1;
		replace `h22' = -normalden(`w2')*(`w2'+(normalden(`w2')/normal(`w2')))/normal(`w2') if $ML_y2 == 0;
		gen double `h23' = (omas_i*`q1'*`bden'*((`rhos'*`delta'*`v2')-`w2'-(((omas_i*`ge2')+(`cc'*normalden(`w2')))/`A'))/`A')*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `h23' = 0 if $ML_y2 == 0;
		gen double `h33' = (((omas_i*`bden'*(`qf'+((`delta'^2)*`w1'*`w2')-(omas_i*`bden'/`A'))/`A')*(1-(tanh(`ihtrho')^2)))-(2*tanh(`ihtrho')*(omas_i*`q1'*`q2'*`bden'/`A')))*(1-(tanh(`ihtrho')^2)) if $ML_y2 == 1;
		replace `h33' = 0 if $ML_y2 == 0;
		tempname d11 d12 d13 d22 d23 d33;
		mlmatsum `lnfj' `d11' = `h11', eq(1);
		mlmatsum `lnfj' `d12' = `h12', eq(1,2);
		mlmatsum `lnfj' `d13' = `h13', eq(1,3);
		mlmatsum `lnfj' `d22' = `h22', eq(2);
		mlmatsum `lnfj' `d23' = `h23', eq(2,3);
		mlmatsum `lnfj' `d33' = `h33', eq(3);
		matrix `H' = (`d11',`d12',`d13' \ `d12'',`d22',`d23' \ `d13'',`d23'',`d33');
	};
end;

program MM1, rclass; /*misclassification independent of covariates*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = runiform();
	gen double u1 = runiform();
	gen byte yo=yt;
	replace yo=1 if (yt==0 & u0>0.95);
	replace yo=0 if (yt==1 & u1>0.80);
	gen double alpha0_i = 0.05;
	gen double alpha1_i = 0.20;
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	replace yo=. if s==0;
	capture probit yo x11 x12 x13;
	if _rc==0 {;
		return scalar b10_Probit = _b[_cons];
		return scalar b11_Probit = _b[x11];
		return scalar b12_Probit = _b[x12];
		return scalar b13_Probit = _b[x13];
	};
	else {;
		return scalar b10_Probit = .;
		return scalar b11_Probit = .;
		return scalar b12_Probit = .;
		return scalar b13_Probit = .;
	};
	reg yo (c.x11 c.x12 c.x13)#c.omas_i;
	matrix coef_lpm=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],((_b[_cons]-0.05)/0.75)-0.5)*2.5;
	matrix colnames coef_lpm = x11 x12 x13 _cons;
	matrix colnames coef_lpm = eq1:;
	matrix b0val = (-2.7081);
	matrix colnames b0val = eq2:_cons;
	matrix b1val = (-1.3218);
	matrix colnames b1val = eq3:_cons;
	matrix coef_lpm_bs=coef_lpm,b0val,b1val;
	ml model lf2 HAS_Probit_lf2 (yo = x11 x12 x13) () () if s==1;
	ml init coef_lpm_bs;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Probit = _b[eq1:_cons];
		return scalar b11_HAS_Probit = _b[eq1:x11];
		return scalar b12_HAS_Probit = _b[eq1:x12];
		return scalar b13_HAS_Probit = _b[eq1:x13];
		nlcom (alpha0: exp(_b[eq2:_cons])/(1+exp(_b[eq2:_cons])+exp(_b[eq3:_cons]))) (alpha1: exp(_b[eq3:_cons])/(1+exp(_b[eq2:_cons])+exp(_b[eq3:_cons]))), post;
		return scalar alpha0_HAS_Probit = _b[alpha0];
		return scalar alpha1_HAS_Probit = _b[alpha1];
	};
	else {;
		return scalar b10_HAS_Probit = .;
		return scalar b11_HAS_Probit = .;
		return scalar b12_HAS_Probit = .;
		return scalar b13_HAS_Probit = .;
		return scalar alpha0_HAS_Probit = .;
		return scalar alpha1_HAS_Probit = .;
	};
	ml model lf2 PP_Probit_lf2 (yo = x11 x12 x13) if s==1;
	ml init coef_lpm;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Probit = _b[_cons];
		return scalar b11_PP_Probit = _b[x11];
		return scalar b12_PP_Probit = _b[x12];
		return scalar b13_PP_Probit = _b[x13];
	};
	else {;
		return scalar b10_PP_Probit = .;
		return scalar b11_PP_Probit = .;
		return scalar b12_PP_Probit = .;
		return scalar b13_PP_Probit = .;
	};
	capture heckprobit yo x11 x12 x13, select(s = x11 x12 x13 x21 x22);
	if _rc==0 {;
		return scalar b10_Heckprobit = _b[yo:_cons];
		return scalar b11_Heckprobit = _b[yo:x11];
		return scalar b12_Heckprobit = _b[yo:x12];
		return scalar b13_Heckprobit = _b[yo:x13];
		return scalar b20_Heckprobit = _b[s:_cons];
		return scalar b21_Heckprobit = _b[s:x21];
		return scalar b22_Heckprobit = _b[s:x22];
		return scalar rho_Heckprobit = tanh(_b[/:athrho]);
	};
	else {;
		return scalar b10_Heckprobit = .;
		return scalar b11_Heckprobit = .;
		return scalar b12_Heckprobit = .;
		return scalar b13_Heckprobit = .;
		return scalar b20_Heckprobit = .;
		return scalar b21_Heckprobit = .;
		return scalar b22_Heckprobit = .;
		return scalar rho_Heckprobit = .;
	};
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	reg yo (c.x11 c.x12 c.x13)#c.omas_i c.IMR#c.omas_i;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],((_b[_cons]-0.05)/0.75)-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix colnames b0val = eq4:_cons;
	matrix colnames b1val = eq5:_cons;
	matrix coef_HAS_Heckprobit1=coef_lpm_sel,coef_sel,coef_ihtrho,b0val,b1val;
	ml model lf2 HAS_Heckprobit1_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) () () (), missing;
	ml init coef_HAS_Heckprobit1;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Heckprobit1 = _b[eq1:_cons];
		return scalar b11_HAS_Heckprobit1 = _b[eq1:x11];
		return scalar b12_HAS_Heckprobit1 = _b[eq1:x12];
		return scalar b13_HAS_Heckprobit1 = _b[eq1:x13];
		return scalar b20_HAS_Heckprobit1 = _b[eq2:_cons];
		return scalar b21_HAS_Heckprobit1 = _b[eq2:x21];
		return scalar b22_HAS_Heckprobit1 = _b[eq2:x22];
		return scalar rho_HAS_Heckprobit1 = tanh(_b[eq3:_cons]);
		nlcom (alpha0: exp(_b[eq4:_cons])/(1+exp(_b[eq4:_cons])+exp(_b[eq5:_cons]))) (alpha1: exp(_b[eq5:_cons])/(1+exp(_b[eq4:_cons])+exp(_b[eq5:_cons]))), post;
		return scalar alpha0_HAS_Heckprobit1 = _b[alpha0];
		return scalar alpha1_HAS_Heckprobit1 = _b[alpha1];
	};
	else {;
		return scalar b10_HAS_Heckprobit1 = .;
		return scalar b11_HAS_Heckprobit1 = .;
		return scalar b12_HAS_Heckprobit1 = .;
		return scalar b13_HAS_Heckprobit1 = .;
		return scalar b20_HAS_Heckprobit1 = .;
		return scalar b21_HAS_Heckprobit1 = .;
		return scalar b22_HAS_Heckprobit1 = .;
		return scalar rho_HAS_Heckprobit1 = .;
		return scalar alpha0_HAS_Heckprobit1 = .;
		return scalar alpha1_HAS_Heckprobit1 = .;
	};
	matrix coef_PP_Heckprobit=coef_lpm_sel,coef_sel,coef_ihtrho;
	ml model lf2 PP_Heckprobit_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) (), missing;
	ml init coef_PP_Heckprobit;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Heckprobit = _b[eq1:_cons];
		return scalar b11_PP_Heckprobit = _b[eq1:x11];
		return scalar b12_PP_Heckprobit = _b[eq1:x12];
		return scalar b13_PP_Heckprobit = _b[eq1:x13];
		return scalar b20_PP_Heckprobit = _b[eq2:_cons];
		return scalar b21_PP_Heckprobit = _b[eq2:x21];
		return scalar b22_PP_Heckprobit = _b[eq2:x22];
		return scalar rho_PP_Heckprobit = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_PP_Heckprobit = .;
		return scalar b11_PP_Heckprobit = .;
		return scalar b12_PP_Heckprobit = .;
		return scalar b13_PP_Heckprobit = .;
		return scalar b20_PP_Heckprobit = .;
		return scalar b21_PP_Heckprobit = .;
		return scalar b22_PP_Heckprobit = .;
		return scalar rho_PP_Heckprobit = .;	
	};
end;

program MM2, rclass; /*misclassification dependent of covariates, cross-tabulation*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	constraint drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = runiform();
	gen double u1 = runiform();
	gen byte yo=yt;
	replace yo=1 if (yt==0 & x11>=1 & x12==0 & u0>0.97);
	replace yo=1 if (yt==0 & x11>=1 & x12==1 & u0>0.96);
	replace yo=1 if (yt==0 & x11<1 & x12==0 & u0>0.94);
	replace yo=1 if (yt==0 & x11<1 & x12==1 & u0>0.92);
	replace yo=0 if (yt==1 & x11>=1 & x12==0 & u1>0.82);
	replace yo=0 if (yt==1 & x11>=1 & x12==1 & u1>0.72);
	replace yo=0 if (yt==1 & x11<1 & x12==0 & u1>0.80);
	replace yo=0 if (yt==1 & x11<1 & x12==1 & u1>0.84);
	gen double alpha0_i = 0.03;
	replace alpha0_i = 0.04 if (x11>=1 & x12==1);
	replace alpha0_i = 0.06 if (x11<1 & x12==0);
	replace alpha0_i = 0.08 if (x11<1 & x12==1);
	gen double alpha1_i = 0.18;
	replace alpha1_i = 0.28 if (x11>=1 & x12==1);
	replace alpha1_i = 0.20 if (x11<1 & x12==0);
	replace alpha1_i = 0.16 if (x11<1 & x12==1);
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	constraint 1 alpha0_i = 1;
	replace yo=. if s==0;
	capture probit yo x11 x12 x13;
	if _rc==0 {;
		return scalar b10_Probit = _b[_cons];
		return scalar b11_Probit = _b[x11];
		return scalar b12_Probit = _b[x12];
		return scalar b13_Probit = _b[x13];
	};
	else {;
		return scalar b10_Probit = .;
		return scalar b11_Probit = .;
		return scalar b12_Probit = .;
		return scalar b13_Probit = .;
	};
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i, constraints(1) noconstant;
	matrix coef_lpm=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	matrix colnames coef_lpm = x11 x12 x13 _cons;
	matrix colnames coef_lpm = eq1:;
	matrix b0val = (-2.7081);
	matrix colnames b0val = eq2:_cons;
	matrix b1val = (-1.3218);
	matrix colnames b1val = eq3:_cons;
	matrix coef_lpm_bs=coef_lpm,b0val,b1val;
	ml model lf2 HAS_Probit_lf2 (yo = x11 x12 x13) () () if s==1;
	ml init coef_lpm_bs;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Probit = _b[eq1:_cons];
		return scalar b11_HAS_Probit = _b[eq1:x11];
		return scalar b12_HAS_Probit = _b[eq1:x12];
		return scalar b13_HAS_Probit = _b[eq1:x13];
	};
	else {;
		return scalar b10_HAS_Probit = .;
		return scalar b11_HAS_Probit = .;
		return scalar b12_HAS_Probit = .;
		return scalar b13_HAS_Probit = .;
	};
	ml model lf2 PP_Probit_lf2 (yo = x11 x12 x13) if s==1;
	ml init coef_lpm;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Probit = _b[_cons];
		return scalar b11_PP_Probit = _b[x11];
		return scalar b12_PP_Probit = _b[x12];
		return scalar b13_PP_Probit = _b[x13];
	};
	else {;
		return scalar b10_PP_Probit = .;
		return scalar b11_PP_Probit = .;
		return scalar b12_PP_Probit = .;
		return scalar b13_PP_Probit = .;
	};
	capture heckprobit yo x11 x12 x13, select(s = x11 x12 x13 x21 x22);
	if _rc==0 {;
		return scalar b10_Heckprobit = _b[yo:_cons];
		return scalar b11_Heckprobit = _b[yo:x11];
		return scalar b12_Heckprobit = _b[yo:x12];
		return scalar b13_Heckprobit = _b[yo:x13];
		return scalar b20_Heckprobit = _b[s:_cons];
		return scalar b21_Heckprobit = _b[s:x21];
		return scalar b22_Heckprobit = _b[s:x22];
		return scalar rho_Heckprobit = tanh(_b[/:athrho]);
	};
	else {;
		return scalar b10_Heckprobit = .;
		return scalar b11_Heckprobit = .;
		return scalar b12_Heckprobit = .;
		return scalar b13_Heckprobit = .;
		return scalar b20_Heckprobit = .;
		return scalar b21_Heckprobit = .;
		return scalar b22_Heckprobit = .;
		return scalar rho_Heckprobit = .;
	};
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i c.IMR#c.omas_i, constraints(1) noconstant;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix colnames b0val = eq4:_cons;
	matrix colnames b1val = eq5:_cons;
	matrix coef_HAS_Heckprobit1=coef_lpm_sel,coef_sel,coef_ihtrho,b0val,b1val;
	ml model lf2 HAS_Heckprobit1_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) () () (), missing;
	ml init coef_HAS_Heckprobit1;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Heckprobit1 = _b[eq1:_cons];
		return scalar b11_HAS_Heckprobit1 = _b[eq1:x11];
		return scalar b12_HAS_Heckprobit1 = _b[eq1:x12];
		return scalar b13_HAS_Heckprobit1 = _b[eq1:x13];
		return scalar b20_HAS_Heckprobit1 = _b[eq2:_cons];
		return scalar b21_HAS_Heckprobit1 = _b[eq2:x21];
		return scalar b22_HAS_Heckprobit1 = _b[eq2:x22];
		return scalar rho_HAS_Heckprobit1 = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_HAS_Heckprobit1 = .;
		return scalar b11_HAS_Heckprobit1 = .;
		return scalar b12_HAS_Heckprobit1 = .;
		return scalar b13_HAS_Heckprobit1 = .;
		return scalar b20_HAS_Heckprobit1 = .;
		return scalar b21_HAS_Heckprobit1 = .;
		return scalar b22_HAS_Heckprobit1 = .;
		return scalar rho_HAS_Heckprobit1 = .;
	};
	matrix coef_PP_Heckprobit=coef_lpm_sel,coef_sel,coef_ihtrho;
	ml model lf2 PP_Heckprobit_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) (), missing;
	ml init coef_PP_Heckprobit;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Heckprobit = _b[eq1:_cons];
		return scalar b11_PP_Heckprobit = _b[eq1:x11];
		return scalar b12_PP_Heckprobit = _b[eq1:x12];
		return scalar b13_PP_Heckprobit = _b[eq1:x13];
		return scalar b20_PP_Heckprobit = _b[eq2:_cons];
		return scalar b21_PP_Heckprobit = _b[eq2:x21];
		return scalar b22_PP_Heckprobit = _b[eq2:x22];
		return scalar rho_PP_Heckprobit = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_PP_Heckprobit = .;
		return scalar b11_PP_Heckprobit = .;
		return scalar b12_PP_Heckprobit = .;
		return scalar b13_PP_Heckprobit = .;
		return scalar b20_PP_Heckprobit = .;
		return scalar b21_PP_Heckprobit = .;
		return scalar b22_PP_Heckprobit = .;
		return scalar rho_PP_Heckprobit = .;	
	};
end;

program MM3, rclass; /*misclassification dependent of covariates, probit type*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	constraint drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = rnormal();
	gen double u1 = rnormal();
	gen double a0star = -1.5-(0.1*x11)-(0.1*x12)+u0;
	gen double a1star = -0.5-(0.2*x11)-(0.3*x12)+u1;
	gen byte yo=yt;
	replace yo=1 if (yt==0 & a0star>0);
	replace yo=0 if (yt==1 & a1star>0);
	gen double alpha0_i = normal(-1.5-(0.1*x11)-(0.1*x12));
	gen double alpha1_i = normal(-0.5-(0.2*x11)-(0.3*x12));
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	constraint 1 alpha0_i = 1;
	replace yo=. if s==0;
	capture probit yo x11 x12 x13;
	if _rc==0 {;
		return scalar b10_Probit = _b[_cons];
		return scalar b11_Probit = _b[x11];
		return scalar b12_Probit = _b[x12];
		return scalar b13_Probit = _b[x13];
	};
	else {;
		return scalar b10_Probit = .;
		return scalar b11_Probit = .;
		return scalar b12_Probit = .;
		return scalar b13_Probit = .;
	};
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i, constraints(1) noconstant;
	matrix coef_lpm=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	matrix colnames coef_lpm = x11 x12 x13 _cons;
	matrix colnames coef_lpm = eq1:;
	matrix b0val = (-2.7081);
	matrix colnames b0val = eq2:_cons;
	matrix b1val = (-1.3218);
	matrix colnames b1val = eq3:_cons;
	matrix coef_lpm_bs=coef_lpm,b0val,b1val;
	ml model lf2 HAS_Probit_lf2 (yo = x11 x12 x13) () () if s==1;
	ml init coef_lpm_bs;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Probit = _b[eq1:_cons];
		return scalar b11_HAS_Probit = _b[eq1:x11];
		return scalar b12_HAS_Probit = _b[eq1:x12];
		return scalar b13_HAS_Probit = _b[eq1:x13];
	};
	else {;
		return scalar b10_HAS_Probit = .;
		return scalar b11_HAS_Probit = .;
		return scalar b12_HAS_Probit = .;
		return scalar b13_HAS_Probit = .;
	};
	ml model lf2 PP_Probit_lf2 (yo = x11 x12 x13) if s==1;
	ml init coef_lpm;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Probit = _b[_cons];
		return scalar b11_PP_Probit = _b[x11];
		return scalar b12_PP_Probit = _b[x12];
		return scalar b13_PP_Probit = _b[x13];
	};
	else {;
		return scalar b10_PP_Probit = .;
		return scalar b11_PP_Probit = .;
		return scalar b12_PP_Probit = .;
		return scalar b13_PP_Probit = .;
	};
	capture heckprobit yo x11 x12 x13, select(s = x11 x12 x13 x21 x22);
	if _rc==0 {;
		return scalar b10_Heckprobit = _b[yo:_cons];
		return scalar b11_Heckprobit = _b[yo:x11];
		return scalar b12_Heckprobit = _b[yo:x12];
		return scalar b13_Heckprobit = _b[yo:x13];
		return scalar b20_Heckprobit = _b[s:_cons];
		return scalar b21_Heckprobit = _b[s:x21];
		return scalar b22_Heckprobit = _b[s:x22];
		return scalar rho_Heckprobit = tanh(_b[/:athrho]);
	};
	else {;
		return scalar b10_Heckprobit = .;
		return scalar b11_Heckprobit = .;
		return scalar b12_Heckprobit = .;
		return scalar b13_Heckprobit = .;
		return scalar b20_Heckprobit = .;
		return scalar b21_Heckprobit = .;
		return scalar b22_Heckprobit = .;
		return scalar rho_Heckprobit = .;
	};
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i c.IMR#c.omas_i, constraints(1) noconstant;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix colnames b0val = eq4:_cons;
	matrix colnames b1val = eq5:_cons;
	matrix coef_HAS_Heckprobit1=coef_lpm_sel,coef_sel,coef_ihtrho,b0val,b1val;
	ml model lf2 HAS_Heckprobit1_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) () () (), missing;
	ml init coef_HAS_Heckprobit1;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Heckprobit1 = _b[eq1:_cons];
		return scalar b11_HAS_Heckprobit1 = _b[eq1:x11];
		return scalar b12_HAS_Heckprobit1 = _b[eq1:x12];
		return scalar b13_HAS_Heckprobit1 = _b[eq1:x13];
		return scalar b20_HAS_Heckprobit1 = _b[eq2:_cons];
		return scalar b21_HAS_Heckprobit1 = _b[eq2:x21];
		return scalar b22_HAS_Heckprobit1 = _b[eq2:x22];
		return scalar rho_HAS_Heckprobit1 = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_HAS_Heckprobit1 = .;
		return scalar b11_HAS_Heckprobit1 = .;
		return scalar b12_HAS_Heckprobit1 = .;
		return scalar b13_HAS_Heckprobit1 = .;
		return scalar b20_HAS_Heckprobit1 = .;
		return scalar b21_HAS_Heckprobit1 = .;
		return scalar b22_HAS_Heckprobit1 = .;
		return scalar rho_HAS_Heckprobit1 = .;
	};
	matrix coef_PP_Heckprobit=coef_lpm_sel,coef_sel,coef_ihtrho;
	ml model lf2 PP_Heckprobit_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) (), missing;
	ml init coef_PP_Heckprobit;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Heckprobit = _b[eq1:_cons];
		return scalar b11_PP_Heckprobit = _b[eq1:x11];
		return scalar b12_PP_Heckprobit = _b[eq1:x12];
		return scalar b13_PP_Heckprobit = _b[eq1:x13];
		return scalar b20_PP_Heckprobit = _b[eq2:_cons];
		return scalar b21_PP_Heckprobit = _b[eq2:x21];
		return scalar b22_PP_Heckprobit = _b[eq2:x22];
		return scalar rho_PP_Heckprobit = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_PP_Heckprobit = .;
		return scalar b11_PP_Heckprobit = .;
		return scalar b12_PP_Heckprobit = .;
		return scalar b13_PP_Heckprobit = .;
		return scalar b20_PP_Heckprobit = .;
		return scalar b21_PP_Heckprobit = .;
		return scalar b22_PP_Heckprobit = .;
		return scalar rho_PP_Heckprobit = .;	
	};
end;

program MM1F, rclass; /*misclassification independent of covariates*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = runiform();
	gen double u1 = runiform();
	gen byte yo=yt;
	replace yo=1 if (yt==0 & u0>0.95);
	replace yo=0 if (yt==1 & u1>0.80);
	gen double alpha0_i = 0.05;
	gen double alpha1_i = 0.20;
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	replace yo=. if s==0;
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	reg yo (c.x11 c.x12 c.x13)#c.omas_i c.IMR#c.omas_i;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],((_b[_cons]-0.05)/0.75)-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix coef_PP_Heckprobit=coef_lpm_sel,coef_sel,coef_ihtrho;
	ml model lf2 PP_Heckprobit_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) (), missing;
	ml init coef_PP_Heckprobit;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Heckprobit = _b[eq1:_cons];
		return scalar b11_PP_Heckprobit = _b[eq1:x11];
		return scalar b12_PP_Heckprobit = _b[eq1:x12];
		return scalar b13_PP_Heckprobit = _b[eq1:x13];
		return scalar b20_PP_Heckprobit = _b[eq2:_cons];
		return scalar b21_PP_Heckprobit = _b[eq2:x21];
		return scalar b22_PP_Heckprobit = _b[eq2:x22];
		return scalar rho_PP_Heckprobit = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_PP_Heckprobit = .;
		return scalar b11_PP_Heckprobit = .;
		return scalar b12_PP_Heckprobit = .;
		return scalar b13_PP_Heckprobit = .;
		return scalar b20_PP_Heckprobit = .;
		return scalar b21_PP_Heckprobit = .;
		return scalar b22_PP_Heckprobit = .;
		return scalar rho_PP_Heckprobit = .;	
	};
end;

program MM2F, rclass; /*misclassification dependent of covariates, cross-tabulation*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	constraint drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = runiform();
	gen double u1 = runiform();
	gen byte yo=yt;
	replace yo=1 if (yt==0 & x11>=1 & x12==0 & u0>0.97);
	replace yo=1 if (yt==0 & x11>=1 & x12==1 & u0>0.96);
	replace yo=1 if (yt==0 & x11<1 & x12==0 & u0>0.94);
	replace yo=1 if (yt==0 & x11<1 & x12==1 & u0>0.92);
	replace yo=0 if (yt==1 & x11>=1 & x12==0 & u1>0.82);
	replace yo=0 if (yt==1 & x11>=1 & x12==1 & u1>0.72);
	replace yo=0 if (yt==1 & x11<1 & x12==0 & u1>0.80);
	replace yo=0 if (yt==1 & x11<1 & x12==1 & u1>0.84);
	gen double alpha0_i = 0.03;
	replace alpha0_i = 0.04 if (x11>=1 & x12==1);
	replace alpha0_i = 0.06 if (x11<1 & x12==0);
	replace alpha0_i = 0.08 if (x11<1 & x12==1);
	gen double alpha1_i = 0.18;
	replace alpha1_i = 0.28 if (x11>=1 & x12==1);
	replace alpha1_i = 0.20 if (x11<1 & x12==0);
	replace alpha1_i = 0.16 if (x11<1 & x12==1);
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	constraint 1 alpha0_i = 1;
	replace yo=. if s==0;
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i c.IMR#c.omas_i, constraints(1) noconstant;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix coef_PP_Heckprobit=coef_lpm_sel,coef_sel,coef_ihtrho;
	ml model lf2 PP_Heckprobit_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) (), missing;
	ml init coef_PP_Heckprobit;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Heckprobit = _b[eq1:_cons];
		return scalar b11_PP_Heckprobit = _b[eq1:x11];
		return scalar b12_PP_Heckprobit = _b[eq1:x12];
		return scalar b13_PP_Heckprobit = _b[eq1:x13];
		return scalar b20_PP_Heckprobit = _b[eq2:_cons];
		return scalar b21_PP_Heckprobit = _b[eq2:x21];
		return scalar b22_PP_Heckprobit = _b[eq2:x22];
		return scalar rho_PP_Heckprobit = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_PP_Heckprobit = .;
		return scalar b11_PP_Heckprobit = .;
		return scalar b12_PP_Heckprobit = .;
		return scalar b13_PP_Heckprobit = .;
		return scalar b20_PP_Heckprobit = .;
		return scalar b21_PP_Heckprobit = .;
		return scalar b22_PP_Heckprobit = .;
		return scalar rho_PP_Heckprobit = .;	
	};
end;

program MM3F, rclass; /*misclassification dependent of covariates, probit type*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	constraint drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = rnormal();
	gen double u1 = rnormal();
	gen double a0star = -1.5-(0.1*x11)-(0.1*x12)+u0;
	gen double a1star = -0.5-(0.2*x11)-(0.3*x12)+u1;
	gen byte yo=yt;
	replace yo=1 if (yt==0 & a0star>0);
	replace yo=0 if (yt==1 & a1star>0);
	gen double alpha0_i = normal(-1.5-(0.1*x11)-(0.1*x12));
	gen double alpha1_i = normal(-0.5-(0.2*x11)-(0.3*x12));
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	constraint 1 alpha0_i = 1;
	replace yo=. if s==0;
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i c.IMR#c.omas_i, constraints(1) noconstant;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix coef_PP_Heckprobit=coef_lpm_sel,coef_sel,coef_ihtrho;
	ml model lf2 PP_Heckprobit_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) (), missing;
	ml init coef_PP_Heckprobit;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_PP_Heckprobit = _b[eq1:_cons];
		return scalar b11_PP_Heckprobit = _b[eq1:x11];
		return scalar b12_PP_Heckprobit = _b[eq1:x12];
		return scalar b13_PP_Heckprobit = _b[eq1:x13];
		return scalar b20_PP_Heckprobit = _b[eq2:_cons];
		return scalar b21_PP_Heckprobit = _b[eq2:x21];
		return scalar b22_PP_Heckprobit = _b[eq2:x22];
		return scalar rho_PP_Heckprobit = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_PP_Heckprobit = .;
		return scalar b11_PP_Heckprobit = .;
		return scalar b12_PP_Heckprobit = .;
		return scalar b13_PP_Heckprobit = .;
		return scalar b20_PP_Heckprobit = .;
		return scalar b21_PP_Heckprobit = .;
		return scalar b22_PP_Heckprobit = .;
		return scalar rho_PP_Heckprobit = .;	
	};
end;

program MM1AG, rclass; /*misclassification independent of covariates*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x11d = (x11<1);
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = runiform();
	gen double u1 = runiform();
	gen byte yo=yt;
	replace yo=1 if (yt==0 & u0>0.95);
	replace yo=0 if (yt==1 & u1>0.80);
	gen double alpha0_i = 0.05;
	gen double alpha1_i = 0.20;
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	replace yo=. if s==0;
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	reg yo (c.x11 c.x12 c.x13)#c.omas_i c.IMR#c.omas_i;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],((_b[_cons]-0.05)/0.75)-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix b0_11=(-2.5123);
	matrix b1_11=(-1.3083);
	matrix b0_12=(-2.2513);
	matrix b1_12=(-1.5581);
	matrix b0_21=(-3.2708);
	matrix b1_21=(-1.4791);
	matrix b0_22=(-2.8332);
	matrix b1_22=(-0.8873);
	matrix colnames b0_11 = eq4:_cons;
	matrix colnames b1_11 = eq5:_cons;
	matrix colnames b0_12 = eq6:_cons;
	matrix colnames b1_12 = eq7:_cons;
	matrix colnames b0_21 = eq8:_cons;
	matrix colnames b1_21 = eq9:_cons;
	matrix colnames b0_22 = eq10:_cons;
	matrix colnames b1_22 = eq11:_cons;
	matrix coef_HAS_Heckprobit2=coef_lpm_sel,coef_sel,coef_ihtrho,b0_11,b1_11,b0_12,b1_12,b0_21,b1_21,b0_22,b1_22;
	ml model lf2 HAS_Heckprobit2_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) () () () () () () () () (), missing;
	ml init coef_HAS_Heckprobit2;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Heckprobit2 = _b[eq1:_cons];
		return scalar b11_HAS_Heckprobit2 = _b[eq1:x11];
		return scalar b12_HAS_Heckprobit2 = _b[eq1:x12];
		return scalar b13_HAS_Heckprobit2 = _b[eq1:x13];
		return scalar b20_HAS_Heckprobit2 = _b[eq2:_cons];
		return scalar b21_HAS_Heckprobit2 = _b[eq2:x21];
		return scalar b22_HAS_Heckprobit2 = _b[eq2:x22];
		return scalar rho_HAS_Heckprobit2 = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_HAS_Heckprobit2 = .;
		return scalar b11_HAS_Heckprobit2 = .;
		return scalar b12_HAS_Heckprobit2 = .;
		return scalar b13_HAS_Heckprobit2 = .;
		return scalar b20_HAS_Heckprobit2 = .;
		return scalar b21_HAS_Heckprobit2 = .;
		return scalar b22_HAS_Heckprobit2 = .;
		return scalar rho_HAS_Heckprobit2 = .;	
	};
end;

program MM2AG, rclass; /*misclassification dependent of covariates, cross-tabulation*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	constraint drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x11d = (x11<1);
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = runiform();
	gen double u1 = runiform();
	gen byte yo=yt;
	replace yo=1 if (yt==0 & x11>=1 & x12==0 & u0>0.97);
	replace yo=1 if (yt==0 & x11>=1 & x12==1 & u0>0.96);
	replace yo=1 if (yt==0 & x11<1 & x12==0 & u0>0.94);
	replace yo=1 if (yt==0 & x11<1 & x12==1 & u0>0.92);
	replace yo=0 if (yt==1 & x11>=1 & x12==0 & u1>0.82);
	replace yo=0 if (yt==1 & x11>=1 & x12==1 & u1>0.72);
	replace yo=0 if (yt==1 & x11<1 & x12==0 & u1>0.80);
	replace yo=0 if (yt==1 & x11<1 & x12==1 & u1>0.84);
	gen double alpha0_i = 0.03;
	replace alpha0_i = 0.04 if (x11>=1 & x12==1);
	replace alpha0_i = 0.06 if (x11<1 & x12==0);
	replace alpha0_i = 0.08 if (x11<1 & x12==1);
	gen double alpha1_i = 0.18;
	replace alpha1_i = 0.28 if (x11>=1 & x12==1);
	replace alpha1_i = 0.20 if (x11<1 & x12==0);
	replace alpha1_i = 0.16 if (x11<1 & x12==1);
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	constraint 1 alpha0_i = 1;
	replace yo=. if s==0;
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i c.IMR#c.omas_i, constraints(1) noconstant;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix b0_11=(-2.5123);
	matrix b1_11=(-1.3083);
	matrix b0_12=(-2.2513);
	matrix b1_12=(-1.5581);
	matrix b0_21=(-3.2708);
	matrix b1_21=(-1.4791);
	matrix b0_22=(-2.8332);
	matrix b1_22=(-0.8873);
	matrix colnames b0_11 = eq4:_cons;
	matrix colnames b1_11 = eq5:_cons;
	matrix colnames b0_12 = eq6:_cons;
	matrix colnames b1_12 = eq7:_cons;
	matrix colnames b0_21 = eq8:_cons;
	matrix colnames b1_21 = eq9:_cons;
	matrix colnames b0_22 = eq10:_cons;
	matrix colnames b1_22 = eq11:_cons;
	matrix coef_HAS_Heckprobit2=coef_lpm_sel,coef_sel,coef_ihtrho,b0_11,b1_11,b0_12,b1_12,b0_21,b1_21,b0_22,b1_22;
	ml model lf2 HAS_Heckprobit2_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) () () () () () () () () (), missing;
	ml init coef_HAS_Heckprobit2;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Heckprobit2 = _b[eq1:_cons];
		return scalar b11_HAS_Heckprobit2 = _b[eq1:x11];
		return scalar b12_HAS_Heckprobit2 = _b[eq1:x12];
		return scalar b13_HAS_Heckprobit2 = _b[eq1:x13];
		return scalar b20_HAS_Heckprobit2 = _b[eq2:_cons];
		return scalar b21_HAS_Heckprobit2 = _b[eq2:x21];
		return scalar b22_HAS_Heckprobit2 = _b[eq2:x22];
		return scalar rho_HAS_Heckprobit2 = tanh(_b[eq3:_cons]);
		nlcom (alpha0_11: exp(_b[eq4:_cons])/(1+exp(_b[eq4:_cons])+exp(_b[eq5:_cons]))) (alpha1_11: exp(_b[eq5:_cons])/(1+exp(_b[eq4:_cons])+exp(_b[eq5:_cons]))) (alpha0_12: exp(_b[eq6:_cons])/(1+exp(_b[eq6:_cons])+exp(_b[eq7:_cons]))) (alpha1_12: exp(_b[eq7:_cons])/(1+exp(_b[eq6:_cons])+exp(_b[eq7:_cons]))) (alpha0_21: exp(_b[eq8:_cons])/(1+exp(_b[eq8:_cons])+exp(_b[eq9:_cons]))) (alpha1_21: exp(_b[eq9:_cons])/(1+exp(_b[eq8:_cons])+exp(_b[eq9:_cons]))) (alpha0_22: exp(_b[eq10:_cons])/(1+exp(_b[eq10:_cons])+exp(_b[eq11:_cons]))) (alpha1_22: exp(_b[eq11:_cons])/(1+exp(_b[eq10:_cons])+exp(_b[eq11:_cons]))), post;
		return scalar alpha0_11_HAS_Heckprobit2 = _b[alpha0_11];
		return scalar alpha1_11_HAS_Heckprobit2 = _b[alpha1_11];
		return scalar alpha0_12_HAS_Heckprobit2 = _b[alpha0_12];
		return scalar alpha1_12_HAS_Heckprobit2 = _b[alpha1_12];
		return scalar alpha0_21_HAS_Heckprobit2 = _b[alpha0_21];
		return scalar alpha1_21_HAS_Heckprobit2 = _b[alpha1_21];
		return scalar alpha0_22_HAS_Heckprobit2 = _b[alpha0_22];
		return scalar alpha1_22_HAS_Heckprobit2 = _b[alpha1_22];
	};
	else {;
		return scalar b10_HAS_Heckprobit2 = .;
		return scalar b11_HAS_Heckprobit2 = .;
		return scalar b12_HAS_Heckprobit2 = .;
		return scalar b13_HAS_Heckprobit2 = .;
		return scalar b20_HAS_Heckprobit2 = .;
		return scalar b21_HAS_Heckprobit2 = .;
		return scalar b22_HAS_Heckprobit2 = .;
		return scalar rho_HAS_Heckprobit2 = .;
		return scalar alpha0_11_HAS_Heckprobit2 = .;
		return scalar alpha1_11_HAS_Heckprobit2 = .;
		return scalar alpha0_12_HAS_Heckprobit2 = .;
		return scalar alpha1_12_HAS_Heckprobit2 = .;
		return scalar alpha0_21_HAS_Heckprobit2 = .;
		return scalar alpha1_21_HAS_Heckprobit2 = .;
		return scalar alpha0_22_HAS_Heckprobit2 = .;
		return scalar alpha1_22_HAS_Heckprobit2 = .;
	};
end;

program MM3AG, rclass; /*misclassification dependent of covariates, probit type*/
	version 16.1;
	args beta20 coef_rho;
	matrix drop _all;
	constraint drop _all;
	scalar drop _all;
	drop _all;
	set obs 5000;
	gen double x11 = exp(rnormal());
	gen byte x11d = (x11<1);
	gen byte x12 = (runiform()>(2/3));
	gen double x13 = runiform();
	gen double x21 = rnormal();
	gen double x22 = rnormal();
	matrix C = (1, `coef_rho' \ `coef_rho', 1);
	drawnorm e1 e2, double corr(C);
	gen byte yt = (-1+(0.2*x11)+(1.5*x12)-(0.6*x13)+e1)>0;
	gen byte s = (`beta20'+(0.8*x21)-(0.5*x22)+e2)>0;
	gen double u0 = rnormal();
	gen double u1 = rnormal();
	gen double a0star = -1.5-(0.1*x11)-(0.1*x12)+u0;
	gen double a1star = -0.5-(0.2*x11)-(0.3*x12)+u1;
	gen byte yo=yt;
	replace yo=1 if (yt==0 & a0star>0);
	replace yo=0 if (yt==1 & a1star>0);
	gen double alpha0_i = normal(-1.5-(0.1*x11)-(0.1*x12));
	gen double alpha1_i = normal(-0.5-(0.2*x11)-(0.3*x12));
	gen double omas_i = 1 - alpha0_i - alpha1_i;
	constraint 1 alpha0_i = 1;
	replace yo=. if s==0;
	probit s x11 x12 x13 x21 x22;
	matrix coef_sel=e(b);
	matrix colnames coef_sel = eq2:;
	predict double xbsel, xb;
	gen double IMR=normalden(xbsel)/normal(xbsel) if s==1;
	gen double omega=IMR*(IMR+xbsel) if s==1;
	sum omega;
	scalar mean_omega=r(mean);
	cnsreg yo alpha0_i (c.x11 c.x12 c.x13)#c.omas_i omas_i c.IMR#c.omas_i, constraints(1) noconstant;
	matrix coef_lpm_sel=(_b[c.x11#c.omas_i],_b[c.x12#c.omas_i],_b[c.x13#c.omas_i],_b[omas_i]-0.5)*2.5;
	predict double res_lpm_sel if s==1, residuals;
	matrix accum EO = res_lpm_sel if s==1, noconstant;
	scalar coef_rho_lpm_sel=_b[c.IMR#c.omas_i]/sqrt((EO[1,1]/e(N))+((_b[c.IMR#c.omas_i]^2)*mean_omega));
	if coef_rho_lpm_sel<=-1 {;
		scalar coef_rho_lpm_sel=-0.9;
	};
	else if coef_rho_lpm_sel>=1 {;
		scalar coef_rho_lpm_sel=0.9;
	};
	matrix coef_ihtrho=(atanh(coef_rho_lpm_sel));
	matrix colnames coef_lpm_sel = x11 x12 x13 _cons;
	matrix colnames coef_lpm_sel = eq1:;
	matrix colnames coef_ihtrho = eq3:_cons;
	matrix b0_11=(-2.5123);
	matrix b1_11=(-1.3083);
	matrix b0_12=(-2.2513);
	matrix b1_12=(-1.5581);
	matrix b0_21=(-3.2708);
	matrix b1_21=(-1.4791);
	matrix b0_22=(-2.8332);
	matrix b1_22=(-0.8873);
	matrix colnames b0_11 = eq4:_cons;
	matrix colnames b1_11 = eq5:_cons;
	matrix colnames b0_12 = eq6:_cons;
	matrix colnames b1_12 = eq7:_cons;
	matrix colnames b0_21 = eq8:_cons;
	matrix colnames b1_21 = eq9:_cons;
	matrix colnames b0_22 = eq10:_cons;
	matrix colnames b1_22 = eq11:_cons;
	matrix coef_HAS_Heckprobit2=coef_lpm_sel,coef_sel,coef_ihtrho,b0_11,b1_11,b0_12,b1_12,b0_21,b1_21,b0_22,b1_22;
	ml model lf2 HAS_Heckprobit2_lf2 (yo = x11 x12 x13) (s = x11 x12 x13 x21 x22) () () () () () () () () (), missing;
	ml init coef_HAS_Heckprobit2;
	ml search;
	capture ml maximize, nrtolerance(1e-8) tolerance(1e-8) difficult;
	if _rc==0 {;
		return scalar b10_HAS_Heckprobit2 = _b[eq1:_cons];
		return scalar b11_HAS_Heckprobit2 = _b[eq1:x11];
		return scalar b12_HAS_Heckprobit2 = _b[eq1:x12];
		return scalar b13_HAS_Heckprobit2 = _b[eq1:x13];
		return scalar b20_HAS_Heckprobit2 = _b[eq2:_cons];
		return scalar b21_HAS_Heckprobit2 = _b[eq2:x21];
		return scalar b22_HAS_Heckprobit2 = _b[eq2:x22];
		return scalar rho_HAS_Heckprobit2 = tanh(_b[eq3:_cons]);
	};
	else {;
		return scalar b10_HAS_Heckprobit2 = .;
		return scalar b11_HAS_Heckprobit2 = .;
		return scalar b12_HAS_Heckprobit2 = .;
		return scalar b13_HAS_Heckprobit2 = .;
		return scalar b20_HAS_Heckprobit2 = .;
		return scalar b21_HAS_Heckprobit2 = .;
		return scalar b22_HAS_Heckprobit2 = .;
		return scalar rho_HAS_Heckprobit2 = .;
	};
end;

*MONTE CARLO STUDY;

*Table 2, first panel, and Table 5, first and second panels;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b9_3_=r(alpha0_HAS_Probit) b10_3_=r(alpha1_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b9_9_=r(alpha0_HAS_Heckprobit1) b10_9_=r(alpha1_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1 0.5 0.2;

sum;

putdocx begin;
putdocx table MM1_05_02 = (10,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1_05_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(1,`c') = ("");
		putdocx table MM1_05_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1_05_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(2,`c') = ("");
		putdocx table MM1_05_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1_05_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(3,`c') = ("");
		putdocx table MM1_05_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1_05_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(4,`c') = ("");
		putdocx table MM1_05_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM1_05_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(5,`c') = ("");
		putdocx table MM1_05_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1_05_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(6,`c') = ("");
		putdocx table MM1_05_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1_05_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(7,`c') = ("");
		putdocx table MM1_05_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1_05_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(8,`c') = ("");
		putdocx table MM1_05_02(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(9,`c') = ((r(mean)-0.05)/0.05), nformat(%4.3f);
		putdocx table MM1_05_02(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(9,`c') = ("");
		putdocx table MM1_05_02(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_02(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM1_05_02(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_02(10,`c') = ("");
		putdocx table MM1_05_02(10,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1_05_02, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM1AG 0.5 0.2;

sum;

putdocx begin;
putdocx table MM1AG_05_02 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1AG_05_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(1,`c') = ("");
		putdocx table MM1AG_05_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1AG_05_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(2,`c') = ("");
		putdocx table MM1AG_05_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1AG_05_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(3,`c') = ("");
		putdocx table MM1AG_05_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1AG_05_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(4,`c') = ("");
		putdocx table MM1AG_05_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM1AG_05_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(5,`c') = ("");
		putdocx table MM1AG_05_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1AG_05_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(6,`c') = ("");
		putdocx table MM1AG_05_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1AG_05_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(7,`c') = ("");
		putdocx table MM1AG_05_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1AG_05_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_02(8,`c') = ("");
		putdocx table MM1AG_05_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1AG_05_02, replace;

clear;

*Table 2, second panel, and Table 5, first and second panels;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b9_3_=r(alpha0_HAS_Probit) b10_3_=r(alpha1_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b9_9_=r(alpha0_HAS_Heckprobit1) b10_9_=r(alpha1_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1 0.5 0.8;

sum;

putdocx begin;
putdocx table MM1_05_08 = (10,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1_05_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(1,`c') = ("");
		putdocx table MM1_05_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1_05_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(2,`c') = ("");
		putdocx table MM1_05_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1_05_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(3,`c') = ("");
		putdocx table MM1_05_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1_05_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(4,`c') = ("");
		putdocx table MM1_05_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM1_05_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(5,`c') = ("");
		putdocx table MM1_05_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1_05_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(6,`c') = ("");
		putdocx table MM1_05_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1_05_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(7,`c') = ("");
		putdocx table MM1_05_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1_05_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(8,`c') = ("");
		putdocx table MM1_05_08(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(9,`c') = ((r(mean)-0.05)/0.05), nformat(%4.3f);
		putdocx table MM1_05_08(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(9,`c') = ("");
		putdocx table MM1_05_08(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM1_05_08(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM1_05_08(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_05_08(10,`c') = ("");
		putdocx table MM1_05_08(10,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1_05_08, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM1AG 0.5 0.8;

sum;

putdocx begin;
putdocx table MM1AG_05_08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1AG_05_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(1,`c') = ("");
		putdocx table MM1AG_05_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1AG_05_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(2,`c') = ("");
		putdocx table MM1AG_05_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1AG_05_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(3,`c') = ("");
		putdocx table MM1AG_05_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1AG_05_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(4,`c') = ("");
		putdocx table MM1AG_05_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM1AG_05_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(5,`c') = ("");
		putdocx table MM1AG_05_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1AG_05_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(6,`c') = ("");
		putdocx table MM1AG_05_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1AG_05_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(7,`c') = ("");
		putdocx table MM1AG_05_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_05_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1AG_05_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_05_08(8,`c') = ("");
		putdocx table MM1AG_05_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1AG_05_08, replace;

clear;

*Table 2, third panel, and Table 5, first and second panels;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b9_3_=r(alpha0_HAS_Probit) b10_3_=r(alpha1_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b9_9_=r(alpha0_HAS_Heckprobit1) b10_9_=r(alpha1_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1 2.18 0.2;

sum;

putdocx begin;
putdocx table MM1_218_02 = (10,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1_218_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(1,`c') = ("");
		putdocx table MM1_218_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1_218_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(2,`c') = ("");
		putdocx table MM1_218_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1_218_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(3,`c') = ("");
		putdocx table MM1_218_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1_218_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(4,`c') = ("");
		putdocx table MM1_218_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM1_218_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(5,`c') = ("");
		putdocx table MM1_218_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1_218_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(6,`c') = ("");
		putdocx table MM1_218_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1_218_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(7,`c') = ("");
		putdocx table MM1_218_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1_218_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(8,`c') = ("");
		putdocx table MM1_218_02(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(9,`c') = ((r(mean)-0.05)/0.05), nformat(%4.3f);
		putdocx table MM1_218_02(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(9,`c') = ("");
		putdocx table MM1_218_02(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_02(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM1_218_02(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_02(10,`c') = ("");
		putdocx table MM1_218_02(10,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1_218_02, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM1AG 2.18 0.2;

sum;

putdocx begin;
putdocx table MM1AG_218_02 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1AG_218_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(1,`c') = ("");
		putdocx table MM1AG_218_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1AG_218_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(2,`c') = ("");
		putdocx table MM1AG_218_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1AG_218_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(3,`c') = ("");
		putdocx table MM1AG_218_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1AG_218_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(4,`c') = ("");
		putdocx table MM1AG_218_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM1AG_218_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(5,`c') = ("");
		putdocx table MM1AG_218_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1AG_218_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(6,`c') = ("");
		putdocx table MM1AG_218_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1AG_218_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(7,`c') = ("");
		putdocx table MM1AG_218_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1AG_218_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_02(8,`c') = ("");
		putdocx table MM1AG_218_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1AG_218_02, replace;

clear;

*Table 2, fourth panel, and Table 5, first and second panels;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b9_3_=r(alpha0_HAS_Probit) b10_3_=r(alpha1_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b9_9_=r(alpha0_HAS_Heckprobit1) b10_9_=r(alpha1_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1 2.18 0.8;

sum;

putdocx begin;
putdocx table MM1_218_08 = (10,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1_218_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(1,`c') = ("");
		putdocx table MM1_218_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1_218_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(2,`c') = ("");
		putdocx table MM1_218_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1_218_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(3,`c') = ("");
		putdocx table MM1_218_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1_218_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(4,`c') = ("");
		putdocx table MM1_218_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM1_218_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(5,`c') = ("");
		putdocx table MM1_218_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1_218_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(6,`c') = ("");
		putdocx table MM1_218_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1_218_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(7,`c') = ("");
		putdocx table MM1_218_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1_218_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(8,`c') = ("");
		putdocx table MM1_218_08(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(9,`c') = ((r(mean)-0.05)/0.05), nformat(%4.3f);
		putdocx table MM1_218_08(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(9,`c') = ("");
		putdocx table MM1_218_08(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM1_218_08(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM1_218_08(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1_218_08(10,`c') = ("");
		putdocx table MM1_218_08(10,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1_218_08, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM1AG 2.18 0.8;

sum;

putdocx begin;
putdocx table MM1AG_218_08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1AG_218_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(1,`c') = ("");
		putdocx table MM1AG_218_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1AG_218_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(2,`c') = ("");
		putdocx table MM1AG_218_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1AG_218_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(3,`c') = ("");
		putdocx table MM1AG_218_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1AG_218_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(4,`c') = ("");
		putdocx table MM1AG_218_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM1AG_218_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(5,`c') = ("");
		putdocx table MM1AG_218_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1AG_218_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(6,`c') = ("");
		putdocx table MM1AG_218_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1AG_218_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(7,`c') = ("");
		putdocx table MM1AG_218_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1AG_218_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1AG_218_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1AG_218_08(8,`c') = ("");
		putdocx table MM1AG_218_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1AG_218_08, replace;

clear;

*Table 3, first panel, and Table 5, third panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2 0.5 0.2;

sum;

putdocx begin;
putdocx table MM2_05_02 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2_05_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(1,`c') = ("");
		putdocx table MM2_05_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2_05_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(2,`c') = ("");
		putdocx table MM2_05_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2_05_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(3,`c') = ("");
		putdocx table MM2_05_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2_05_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(4,`c') = ("");
		putdocx table MM2_05_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM2_05_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(5,`c') = ("");
		putdocx table MM2_05_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2_05_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(6,`c') = ("");
		putdocx table MM2_05_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2_05_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(7,`c') = ("");
		putdocx table MM2_05_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2_05_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_02(8,`c') = ("");
		putdocx table MM2_05_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2_05_02, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2) b9_1_=r(alpha0_11_HAS_Heckprobit2) b10_1_=r(alpha1_11_HAS_Heckprobit2) b11_1_=r(alpha0_12_HAS_Heckprobit2) b12_1_=r(alpha1_12_HAS_Heckprobit2) b13_1_=r(alpha0_21_HAS_Heckprobit2) b14_1_=r(alpha1_21_HAS_Heckprobit2) b15_1_=r(alpha0_22_HAS_Heckprobit2) b16_1_=r(alpha1_22_HAS_Heckprobit2), reps(500) seed(376): MM2AG 0.5 0.2;

sum;

putdocx begin;
putdocx table MM2AG_05_02 = (16,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2AG_05_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(1,`c') = ("");
		putdocx table MM2AG_05_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2AG_05_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(2,`c') = ("");
		putdocx table MM2AG_05_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2AG_05_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(3,`c') = ("");
		putdocx table MM2AG_05_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2AG_05_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(4,`c') = ("");
		putdocx table MM2AG_05_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM2AG_05_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(5,`c') = ("");
		putdocx table MM2AG_05_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2AG_05_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(6,`c') = ("");
		putdocx table MM2AG_05_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2AG_05_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(7,`c') = ("");
		putdocx table MM2AG_05_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2AG_05_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(8,`c') = ("");
		putdocx table MM2AG_05_02(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(9,`c') = ((r(mean)-0.06)/0.06), nformat(%4.3f);
		putdocx table MM2AG_05_02(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(9,`c') = ("");
		putdocx table MM2AG_05_02(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM2AG_05_02(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(10,`c') = ("");
		putdocx table MM2AG_05_02(10,`=`c'+1') = ("");
	};
	capture summarize b11_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(11,`c') = ((r(mean)-0.08)/0.08), nformat(%4.3f);
		putdocx table MM2AG_05_02(11,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(11,`c') = ("");
		putdocx table MM2AG_05_02(11,`=`c'+1') = ("");
	};
	capture summarize b12_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(12,`c') = ((r(mean)-0.16)/0.16), nformat(%4.3f);
		putdocx table MM2AG_05_02(12,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(12,`c') = ("");
		putdocx table MM2AG_05_02(12,`=`c'+1') = ("");
	};
	capture summarize b13_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(13,`c') = ((r(mean)-0.03)/0.03), nformat(%4.3f);
		putdocx table MM2AG_05_02(13,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(13,`c') = ("");
		putdocx table MM2AG_05_02(13,`=`c'+1') = ("");
	};
	capture summarize b14_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(14,`c') = ((r(mean)-0.18)/0.18), nformat(%4.3f);
		putdocx table MM2AG_05_02(14,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(14,`c') = ("");
		putdocx table MM2AG_05_02(14,`=`c'+1') = ("");
	};
	capture summarize b15_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(15,`c') = ((r(mean)-0.04)/0.04), nformat(%4.3f);
		putdocx table MM2AG_05_02(15,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(15,`c') = ("");
		putdocx table MM2AG_05_02(15,`=`c'+1') = ("");
	};
	capture summarize b16_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_02(16,`c') = ((r(mean)-0.28)/0.28), nformat(%4.3f);
		putdocx table MM2AG_05_02(16,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_02(16,`c') = ("");
		putdocx table MM2AG_05_02(16,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2AG_05_02, replace;

clear;

*Table 3, second panel, and Table 5, third panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2 0.5 0.8;

sum;

putdocx begin;
putdocx table MM2_05_08 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2_05_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(1,`c') = ("");
		putdocx table MM2_05_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2_05_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(2,`c') = ("");
		putdocx table MM2_05_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2_05_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(3,`c') = ("");
		putdocx table MM2_05_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2_05_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(4,`c') = ("");
		putdocx table MM2_05_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM2_05_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(5,`c') = ("");
		putdocx table MM2_05_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2_05_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(6,`c') = ("");
		putdocx table MM2_05_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2_05_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(7,`c') = ("");
		putdocx table MM2_05_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2_05_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2_05_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_05_08(8,`c') = ("");
		putdocx table MM2_05_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2_05_08, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2) b9_1_=r(alpha0_11_HAS_Heckprobit2) b10_1_=r(alpha1_11_HAS_Heckprobit2) b11_1_=r(alpha0_12_HAS_Heckprobit2) b12_1_=r(alpha1_12_HAS_Heckprobit2) b13_1_=r(alpha0_21_HAS_Heckprobit2) b14_1_=r(alpha1_21_HAS_Heckprobit2) b15_1_=r(alpha0_22_HAS_Heckprobit2) b16_1_=r(alpha1_22_HAS_Heckprobit2), reps(500) seed(376): MM2AG 0.5 0.8;

sum;

putdocx begin;
putdocx table MM2AG_05_08 = (16,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2AG_05_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(1,`c') = ("");
		putdocx table MM2AG_05_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2AG_05_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(2,`c') = ("");
		putdocx table MM2AG_05_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2AG_05_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(3,`c') = ("");
		putdocx table MM2AG_05_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2AG_05_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(4,`c') = ("");
		putdocx table MM2AG_05_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM2AG_05_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(5,`c') = ("");
		putdocx table MM2AG_05_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2AG_05_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(6,`c') = ("");
		putdocx table MM2AG_05_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2AG_05_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(7,`c') = ("");
		putdocx table MM2AG_05_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2AG_05_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(8,`c') = ("");
		putdocx table MM2AG_05_08(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(9,`c') = ((r(mean)-0.06)/0.06), nformat(%4.3f);
		putdocx table MM2AG_05_08(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(9,`c') = ("");
		putdocx table MM2AG_05_08(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM2AG_05_08(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(10,`c') = ("");
		putdocx table MM2AG_05_08(10,`=`c'+1') = ("");
	};
	capture summarize b11_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(11,`c') = ((r(mean)-0.08)/0.08), nformat(%4.3f);
		putdocx table MM2AG_05_08(11,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(11,`c') = ("");
		putdocx table MM2AG_05_08(11,`=`c'+1') = ("");
	};
	capture summarize b12_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(12,`c') = ((r(mean)-0.16)/0.16), nformat(%4.3f);
		putdocx table MM2AG_05_08(12,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(12,`c') = ("");
		putdocx table MM2AG_05_08(12,`=`c'+1') = ("");
	};
	capture summarize b13_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(13,`c') = ((r(mean)-0.03)/0.03), nformat(%4.3f);
		putdocx table MM2AG_05_08(13,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(13,`c') = ("");
		putdocx table MM2AG_05_08(13,`=`c'+1') = ("");
	};
	capture summarize b14_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(14,`c') = ((r(mean)-0.18)/0.18), nformat(%4.3f);
		putdocx table MM2AG_05_08(14,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(14,`c') = ("");
		putdocx table MM2AG_05_08(14,`=`c'+1') = ("");
	};
	capture summarize b15_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(15,`c') = ((r(mean)-0.04)/0.04), nformat(%4.3f);
		putdocx table MM2AG_05_08(15,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(15,`c') = ("");
		putdocx table MM2AG_05_08(15,`=`c'+1') = ("");
	};
	capture summarize b16_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_05_08(16,`c') = ((r(mean)-0.28)/0.28), nformat(%4.3f);
		putdocx table MM2AG_05_08(16,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_05_08(16,`c') = ("");
		putdocx table MM2AG_05_08(16,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2AG_05_08, replace;

clear;

*Table 3, third panel, and Table 5, third panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2 2.18 0.2;

sum;

putdocx begin;
putdocx table MM2_218_02 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2_218_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(1,`c') = ("");
		putdocx table MM2_218_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2_218_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(2,`c') = ("");
		putdocx table MM2_218_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2_218_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(3,`c') = ("");
		putdocx table MM2_218_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2_218_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(4,`c') = ("");
		putdocx table MM2_218_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM2_218_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(5,`c') = ("");
		putdocx table MM2_218_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2_218_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(6,`c') = ("");
		putdocx table MM2_218_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2_218_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(7,`c') = ("");
		putdocx table MM2_218_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2_218_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_02(8,`c') = ("");
		putdocx table MM2_218_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2_218_02, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2) b9_1_=r(alpha0_11_HAS_Heckprobit2) b10_1_=r(alpha1_11_HAS_Heckprobit2) b11_1_=r(alpha0_12_HAS_Heckprobit2) b12_1_=r(alpha1_12_HAS_Heckprobit2) b13_1_=r(alpha0_21_HAS_Heckprobit2) b14_1_=r(alpha1_21_HAS_Heckprobit2) b15_1_=r(alpha0_22_HAS_Heckprobit2) b16_1_=r(alpha1_22_HAS_Heckprobit2), reps(500) seed(376): MM2AG 2.18 0.2;

sum;

putdocx begin;
putdocx table MM2AG_218_02 = (16,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2AG_218_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(1,`c') = ("");
		putdocx table MM2AG_218_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2AG_218_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(2,`c') = ("");
		putdocx table MM2AG_218_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2AG_218_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(3,`c') = ("");
		putdocx table MM2AG_218_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2AG_218_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(4,`c') = ("");
		putdocx table MM2AG_218_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM2AG_218_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(5,`c') = ("");
		putdocx table MM2AG_218_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2AG_218_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(6,`c') = ("");
		putdocx table MM2AG_218_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2AG_218_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(7,`c') = ("");
		putdocx table MM2AG_218_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2AG_218_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(8,`c') = ("");
		putdocx table MM2AG_218_02(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(9,`c') = ((r(mean)-0.06)/0.06), nformat(%4.3f);
		putdocx table MM2AG_218_02(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(9,`c') = ("");
		putdocx table MM2AG_218_02(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM2AG_218_02(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(10,`c') = ("");
		putdocx table MM2AG_218_02(10,`=`c'+1') = ("");
	};
	capture summarize b11_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(11,`c') = ((r(mean)-0.08)/0.08), nformat(%4.3f);
		putdocx table MM2AG_218_02(11,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(11,`c') = ("");
		putdocx table MM2AG_218_02(11,`=`c'+1') = ("");
	};
	capture summarize b12_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(12,`c') = ((r(mean)-0.16)/0.16), nformat(%4.3f);
		putdocx table MM2AG_218_02(12,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(12,`c') = ("");
		putdocx table MM2AG_218_02(12,`=`c'+1') = ("");
	};
	capture summarize b13_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(13,`c') = ((r(mean)-0.03)/0.03), nformat(%4.3f);
		putdocx table MM2AG_218_02(13,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(13,`c') = ("");
		putdocx table MM2AG_218_02(13,`=`c'+1') = ("");
	};
	capture summarize b14_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(14,`c') = ((r(mean)-0.18)/0.18), nformat(%4.3f);
		putdocx table MM2AG_218_02(14,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(14,`c') = ("");
		putdocx table MM2AG_218_02(14,`=`c'+1') = ("");
	};
	capture summarize b15_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(15,`c') = ((r(mean)-0.04)/0.04), nformat(%4.3f);
		putdocx table MM2AG_218_02(15,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(15,`c') = ("");
		putdocx table MM2AG_218_02(15,`=`c'+1') = ("");
	};
	capture summarize b16_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_02(16,`c') = ((r(mean)-0.28)/0.28), nformat(%4.3f);
		putdocx table MM2AG_218_02(16,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_02(16,`c') = ("");
		putdocx table MM2AG_218_02(16,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2AG_218_02, replace;

clear;

*Table 3, fourth panel, and Table 5, third panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2 2.18 0.8;

sum;

putdocx begin;
putdocx table MM2_218_08 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2_218_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(1,`c') = ("");
		putdocx table MM2_218_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2_218_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(2,`c') = ("");
		putdocx table MM2_218_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2_218_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(3,`c') = ("");
		putdocx table MM2_218_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2_218_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(4,`c') = ("");
		putdocx table MM2_218_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM2_218_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(5,`c') = ("");
		putdocx table MM2_218_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2_218_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(6,`c') = ("");
		putdocx table MM2_218_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2_218_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(7,`c') = ("");
		putdocx table MM2_218_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2_218_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2_218_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2_218_08(8,`c') = ("");
		putdocx table MM2_218_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2_218_08, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2) b9_1_=r(alpha0_11_HAS_Heckprobit2) b10_1_=r(alpha1_11_HAS_Heckprobit2) b11_1_=r(alpha0_12_HAS_Heckprobit2) b12_1_=r(alpha1_12_HAS_Heckprobit2) b13_1_=r(alpha0_21_HAS_Heckprobit2) b14_1_=r(alpha1_21_HAS_Heckprobit2) b15_1_=r(alpha0_22_HAS_Heckprobit2) b16_1_=r(alpha1_22_HAS_Heckprobit2), reps(500) seed(376): MM2AG 2.18 0.8;

sum;

putdocx begin;
putdocx table MM2AG_218_08 = (16,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2AG_218_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(1,`c') = ("");
		putdocx table MM2AG_218_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2AG_218_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(2,`c') = ("");
		putdocx table MM2AG_218_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2AG_218_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(3,`c') = ("");
		putdocx table MM2AG_218_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2AG_218_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(4,`c') = ("");
		putdocx table MM2AG_218_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM2AG_218_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(5,`c') = ("");
		putdocx table MM2AG_218_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2AG_218_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(6,`c') = ("");
		putdocx table MM2AG_218_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2AG_218_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(7,`c') = ("");
		putdocx table MM2AG_218_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2AG_218_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(8,`c') = ("");
		putdocx table MM2AG_218_08(8,`=`c'+1') = ("");
	};
	capture summarize b9_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(9,`c') = ((r(mean)-0.06)/0.06), nformat(%4.3f);
		putdocx table MM2AG_218_08(9,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(9,`c') = ("");
		putdocx table MM2AG_218_08(9,`=`c'+1') = ("");
	};
	capture summarize b10_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(10,`c') = ((r(mean)-0.20)/0.20), nformat(%4.3f);
		putdocx table MM2AG_218_08(10,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(10,`c') = ("");
		putdocx table MM2AG_218_08(10,`=`c'+1') = ("");
	};
	capture summarize b11_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(11,`c') = ((r(mean)-0.08)/0.08), nformat(%4.3f);
		putdocx table MM2AG_218_08(11,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(11,`c') = ("");
		putdocx table MM2AG_218_08(11,`=`c'+1') = ("");
	};
	capture summarize b12_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(12,`c') = ((r(mean)-0.16)/0.16), nformat(%4.3f);
		putdocx table MM2AG_218_08(12,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(12,`c') = ("");
		putdocx table MM2AG_218_08(12,`=`c'+1') = ("");
	};
	capture summarize b13_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(13,`c') = ((r(mean)-0.03)/0.03), nformat(%4.3f);
		putdocx table MM2AG_218_08(13,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(13,`c') = ("");
		putdocx table MM2AG_218_08(13,`=`c'+1') = ("");
	};
	capture summarize b14_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(14,`c') = ((r(mean)-0.18)/0.18), nformat(%4.3f);
		putdocx table MM2AG_218_08(14,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(14,`c') = ("");
		putdocx table MM2AG_218_08(14,`=`c'+1') = ("");
	};
	capture summarize b15_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(15,`c') = ((r(mean)-0.04)/0.04), nformat(%4.3f);
		putdocx table MM2AG_218_08(15,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(15,`c') = ("");
		putdocx table MM2AG_218_08(15,`=`c'+1') = ("");
	};
	capture summarize b16_`c'_;
	if _rc==0 {;
		putdocx table MM2AG_218_08(16,`c') = ((r(mean)-0.28)/0.28), nformat(%4.3f);
		putdocx table MM2AG_218_08(16,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2AG_218_08(16,`c') = ("");
		putdocx table MM2AG_218_08(16,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2AG_218_08, replace;

clear;

*Table 4, first panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3 0.5 0.2;

sum;

putdocx begin;
putdocx table MM3_05_02 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3_05_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(1,`c') = ("");
		putdocx table MM3_05_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3_05_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(2,`c') = ("");
		putdocx table MM3_05_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3_05_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(3,`c') = ("");
		putdocx table MM3_05_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3_05_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(4,`c') = ("");
		putdocx table MM3_05_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM3_05_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(5,`c') = ("");
		putdocx table MM3_05_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3_05_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(6,`c') = ("");
		putdocx table MM3_05_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3_05_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(7,`c') = ("");
		putdocx table MM3_05_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3_05_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_02(8,`c') = ("");
		putdocx table MM3_05_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3_05_02, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM3AG 0.5 0.2;

sum;

putdocx begin;
putdocx table MM3AG_05_02 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3AG_05_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(1,`c') = ("");
		putdocx table MM3AG_05_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3AG_05_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(2,`c') = ("");
		putdocx table MM3AG_05_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3AG_05_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(3,`c') = ("");
		putdocx table MM3AG_05_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3AG_05_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(4,`c') = ("");
		putdocx table MM3AG_05_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM3AG_05_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(5,`c') = ("");
		putdocx table MM3AG_05_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3AG_05_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(6,`c') = ("");
		putdocx table MM3AG_05_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3AG_05_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(7,`c') = ("");
		putdocx table MM3AG_05_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3AG_05_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_02(8,`c') = ("");
		putdocx table MM3AG_05_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3AG_05_02, replace;

clear;

*Table 4, second panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3 0.5 0.8;

sum;

putdocx begin;
putdocx table MM3_05_08 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3_05_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(1,`c') = ("");
		putdocx table MM3_05_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3_05_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(2,`c') = ("");
		putdocx table MM3_05_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3_05_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(3,`c') = ("");
		putdocx table MM3_05_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3_05_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(4,`c') = ("");
		putdocx table MM3_05_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM3_05_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(5,`c') = ("");
		putdocx table MM3_05_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3_05_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(6,`c') = ("");
		putdocx table MM3_05_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3_05_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(7,`c') = ("");
		putdocx table MM3_05_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3_05_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3_05_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_05_08(8,`c') = ("");
		putdocx table MM3_05_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3_05_08, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM3AG 0.5 0.8;

sum;

putdocx begin;
putdocx table MM3AG_05_08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3AG_05_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(1,`c') = ("");
		putdocx table MM3AG_05_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3AG_05_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(2,`c') = ("");
		putdocx table MM3AG_05_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3AG_05_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(3,`c') = ("");
		putdocx table MM3AG_05_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3AG_05_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(4,`c') = ("");
		putdocx table MM3AG_05_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM3AG_05_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(5,`c') = ("");
		putdocx table MM3AG_05_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3AG_05_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(6,`c') = ("");
		putdocx table MM3AG_05_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3AG_05_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(7,`c') = ("");
		putdocx table MM3AG_05_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_05_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3AG_05_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_05_08(8,`c') = ("");
		putdocx table MM3AG_05_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3AG_05_08, replace;

clear;

*Table 4, third panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3 2.18 0.2;

sum;

putdocx begin;
putdocx table MM3_218_02 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3_218_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(1,`c') = ("");
		putdocx table MM3_218_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3_218_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(2,`c') = ("");
		putdocx table MM3_218_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3_218_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(3,`c') = ("");
		putdocx table MM3_218_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3_218_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(4,`c') = ("");
		putdocx table MM3_218_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM3_218_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(5,`c') = ("");
		putdocx table MM3_218_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3_218_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(6,`c') = ("");
		putdocx table MM3_218_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3_218_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(7,`c') = ("");
		putdocx table MM3_218_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3_218_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_02(8,`c') = ("");
		putdocx table MM3_218_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3_218_02, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM3AG 2.18 0.2;

sum;

putdocx begin;
putdocx table MM3AG_218_02 = (8,14); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)13 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3AG_218_02(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(1,`c') = ("");
		putdocx table MM3AG_218_02(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3AG_218_02(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(2,`c') = ("");
		putdocx table MM3AG_218_02(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3AG_218_02(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(3,`c') = ("");
		putdocx table MM3AG_218_02(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3AG_218_02(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(4,`c') = ("");
		putdocx table MM3AG_218_02(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM3AG_218_02(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(5,`c') = ("");
		putdocx table MM3AG_218_02(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3AG_218_02(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(6,`c') = ("");
		putdocx table MM3AG_218_02(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3AG_218_02(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(7,`c') = ("");
		putdocx table MM3AG_218_02(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_02(8,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3AG_218_02(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_02(8,`c') = ("");
		putdocx table MM3AG_218_02(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3AG_218_02, replace;

clear;

*Table 4, fourth panel;

simulate b1_1_=r(b10_Probit) b2_1_=r(b11_Probit) b3_1_=r(b12_Probit) b4_1_=r(b13_Probit) b1_3_=r(b10_HAS_Probit) b2_3_=r(b11_HAS_Probit) b3_3_=r(b12_HAS_Probit) b4_3_=r(b13_HAS_Probit) b1_5_=r(b10_PP_Probit) b2_5_=r(b11_PP_Probit) b3_5_=r(b12_PP_Probit) b4_5_=r(b13_PP_Probit) b1_7_=r(b10_Heckprobit) b2_7_=r(b11_Heckprobit) b3_7_=r(b12_Heckprobit) b4_7_=r(b13_Heckprobit) b5_7_=r(b20_Heckprobit) b6_7_=r(b21_Heckprobit) b7_7_=r(b22_Heckprobit) b8_7_=r(rho_Heckprobit) b1_9_=r(b10_HAS_Heckprobit1) b2_9_=r(b11_HAS_Heckprobit1) b3_9_=r(b12_HAS_Heckprobit1) b4_9_=r(b13_HAS_Heckprobit1) b5_9_=r(b20_HAS_Heckprobit1) b6_9_=r(b21_HAS_Heckprobit1) b7_9_=r(b22_HAS_Heckprobit1) b8_9_=r(rho_HAS_Heckprobit1) b1_11_=r(b10_PP_Heckprobit) b2_11_=r(b11_PP_Heckprobit) b3_11_=r(b12_PP_Heckprobit) b4_11_=r(b13_PP_Heckprobit) b5_11_=r(b20_PP_Heckprobit) b6_11_=r(b21_PP_Heckprobit) b7_11_=r(b22_PP_Heckprobit) b8_11_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3 2.18 0.8;

sum;

putdocx begin;
putdocx table MM3_218_08 = (8,12); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(2)11 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3_218_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(1,`c') = ("");
		putdocx table MM3_218_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3_218_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(2,`c') = ("");
		putdocx table MM3_218_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3_218_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(3,`c') = ("");
		putdocx table MM3_218_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3_218_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(4,`c') = ("");
		putdocx table MM3_218_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM3_218_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(5,`c') = ("");
		putdocx table MM3_218_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3_218_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(6,`c') = ("");
		putdocx table MM3_218_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3_218_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(7,`c') = ("");
		putdocx table MM3_218_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3_218_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3_218_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3_218_08(8,`c') = ("");
		putdocx table MM3_218_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3_218_08, replace;

clear;

simulate b1_1_=r(b10_HAS_Heckprobit2) b2_1_=r(b11_HAS_Heckprobit2) b3_1_=r(b12_HAS_Heckprobit2) b4_1_=r(b13_HAS_Heckprobit2) b5_1_=r(b20_HAS_Heckprobit2) b6_1_=r(b21_HAS_Heckprobit2) b7_1_=r(b22_HAS_Heckprobit2) b8_1_=r(rho_HAS_Heckprobit2), reps(500) seed(376): MM3AG 2.18 0.8;

sum;

putdocx begin;
putdocx table MM3AG_218_08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3AG_218_08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(1,`c') = ("");
		putdocx table MM3AG_218_08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3AG_218_08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(2,`c') = ("");
		putdocx table MM3AG_218_08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3AG_218_08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(3,`c') = ("");
		putdocx table MM3AG_218_08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3AG_218_08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(4,`c') = ("");
		putdocx table MM3AG_218_08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM3AG_218_08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(5,`c') = ("");
		putdocx table MM3AG_218_08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3AG_218_08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(6,`c') = ("");
		putdocx table MM3AG_218_08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3AG_218_08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(7,`c') = ("");
		putdocx table MM3AG_218_08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3AG_218_08(8,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3AG_218_08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3AG_218_08(8,`c') = ("");
		putdocx table MM3AG_218_08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3AG_218_08, replace;

clear;

*Table 6, first panel;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1F 0.5 -0.9;

sum;

putdocx begin;
putdocx table MM1F_05_m09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1F_05_m09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(1,`c') = ("");
		putdocx table MM1F_05_m09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1F_05_m09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(2,`c') = ("");
		putdocx table MM1F_05_m09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1F_05_m09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(3,`c') = ("");
		putdocx table MM1F_05_m09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1F_05_m09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(4,`c') = ("");
		putdocx table MM1F_05_m09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM1F_05_m09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(5,`c') = ("");
		putdocx table MM1F_05_m09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1F_05_m09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(6,`c') = ("");
		putdocx table MM1F_05_m09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1F_05_m09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(7,`c') = ("");
		putdocx table MM1F_05_m09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m09(8,`c') = ((r(mean)-(-0.9))/(-0.9)), nformat(%4.3f);
		putdocx table MM1F_05_m09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m09(8,`c') = ("");
		putdocx table MM1F_05_m09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1F_05_m09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1F 0.5 -0.8;

sum;

putdocx begin;
putdocx table MM1F_05_m08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1F_05_m08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(1,`c') = ("");
		putdocx table MM1F_05_m08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1F_05_m08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(2,`c') = ("");
		putdocx table MM1F_05_m08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1F_05_m08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(3,`c') = ("");
		putdocx table MM1F_05_m08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1F_05_m08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(4,`c') = ("");
		putdocx table MM1F_05_m08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM1F_05_m08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(5,`c') = ("");
		putdocx table MM1F_05_m08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1F_05_m08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(6,`c') = ("");
		putdocx table MM1F_05_m08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1F_05_m08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(7,`c') = ("");
		putdocx table MM1F_05_m08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_m08(8,`c') = ((r(mean)-(-0.8))/(-0.8)), nformat(%4.3f);
		putdocx table MM1F_05_m08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_m08(8,`c') = ("");
		putdocx table MM1F_05_m08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1F_05_m08, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1F 0.5 0.9;

sum;

putdocx begin;
putdocx table MM1F_05_09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1F_05_09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(1,`c') = ("");
		putdocx table MM1F_05_09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1F_05_09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(2,`c') = ("");
		putdocx table MM1F_05_09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1F_05_09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(3,`c') = ("");
		putdocx table MM1F_05_09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1F_05_09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(4,`c') = ("");
		putdocx table MM1F_05_09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM1F_05_09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(5,`c') = ("");
		putdocx table MM1F_05_09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1F_05_09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(6,`c') = ("");
		putdocx table MM1F_05_09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1F_05_09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(7,`c') = ("");
		putdocx table MM1F_05_09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1F_05_09(8,`c') = ((r(mean)-0.9)/0.9), nformat(%4.3f);
		putdocx table MM1F_05_09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_05_09(8,`c') = ("");
		putdocx table MM1F_05_09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1F_05_09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1F 2.18 -0.9;

sum;

putdocx begin;
putdocx table MM1F_218_m09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1F_218_m09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(1,`c') = ("");
		putdocx table MM1F_218_m09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1F_218_m09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(2,`c') = ("");
		putdocx table MM1F_218_m09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1F_218_m09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(3,`c') = ("");
		putdocx table MM1F_218_m09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1F_218_m09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(4,`c') = ("");
		putdocx table MM1F_218_m09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM1F_218_m09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(5,`c') = ("");
		putdocx table MM1F_218_m09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1F_218_m09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(6,`c') = ("");
		putdocx table MM1F_218_m09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1F_218_m09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(7,`c') = ("");
		putdocx table MM1F_218_m09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m09(8,`c') = ((r(mean)-(-0.9))/(-0.9)), nformat(%4.3f);
		putdocx table MM1F_218_m09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m09(8,`c') = ("");
		putdocx table MM1F_218_m09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1F_218_m09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1F 2.18 -0.8;

sum;

putdocx begin;
putdocx table MM1F_218_m08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1F_218_m08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(1,`c') = ("");
		putdocx table MM1F_218_m08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1F_218_m08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(2,`c') = ("");
		putdocx table MM1F_218_m08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1F_218_m08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(3,`c') = ("");
		putdocx table MM1F_218_m08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1F_218_m08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(4,`c') = ("");
		putdocx table MM1F_218_m08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM1F_218_m08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(5,`c') = ("");
		putdocx table MM1F_218_m08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1F_218_m08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(6,`c') = ("");
		putdocx table MM1F_218_m08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1F_218_m08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(7,`c') = ("");
		putdocx table MM1F_218_m08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_m08(8,`c') = ((r(mean)-(-0.8))/(-0.8)), nformat(%4.3f);
		putdocx table MM1F_218_m08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_m08(8,`c') = ("");
		putdocx table MM1F_218_m08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1F_218_m08, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM1F 2.18 0.9;

sum;

putdocx begin;
putdocx table MM1F_218_09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM1F_218_09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(1,`c') = ("");
		putdocx table MM1F_218_09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM1F_218_09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(2,`c') = ("");
		putdocx table MM1F_218_09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM1F_218_09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(3,`c') = ("");
		putdocx table MM1F_218_09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM1F_218_09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(4,`c') = ("");
		putdocx table MM1F_218_09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM1F_218_09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(5,`c') = ("");
		putdocx table MM1F_218_09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM1F_218_09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(6,`c') = ("");
		putdocx table MM1F_218_09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM1F_218_09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(7,`c') = ("");
		putdocx table MM1F_218_09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM1F_218_09(8,`c') = ((r(mean)-0.9)/0.9), nformat(%4.3f);
		putdocx table MM1F_218_09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM1F_218_09(8,`c') = ("");
		putdocx table MM1F_218_09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM1F_218_09, replace;

clear;

*Table 6, second panel;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2F 0.5 -0.9;

sum;

putdocx begin;
putdocx table MM2F_05_m09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2F_05_m09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(1,`c') = ("");
		putdocx table MM2F_05_m09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2F_05_m09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(2,`c') = ("");
		putdocx table MM2F_05_m09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2F_05_m09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(3,`c') = ("");
		putdocx table MM2F_05_m09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2F_05_m09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(4,`c') = ("");
		putdocx table MM2F_05_m09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM2F_05_m09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(5,`c') = ("");
		putdocx table MM2F_05_m09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2F_05_m09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(6,`c') = ("");
		putdocx table MM2F_05_m09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2F_05_m09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(7,`c') = ("");
		putdocx table MM2F_05_m09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m09(8,`c') = ((r(mean)-(-0.9))/(-0.9)), nformat(%4.3f);
		putdocx table MM2F_05_m09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m09(8,`c') = ("");
		putdocx table MM2F_05_m09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2F_05_m09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2F 0.5 -0.8;

sum;

putdocx begin;
putdocx table MM2F_05_m08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2F_05_m08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(1,`c') = ("");
		putdocx table MM2F_05_m08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2F_05_m08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(2,`c') = ("");
		putdocx table MM2F_05_m08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2F_05_m08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(3,`c') = ("");
		putdocx table MM2F_05_m08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2F_05_m08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(4,`c') = ("");
		putdocx table MM2F_05_m08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM2F_05_m08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(5,`c') = ("");
		putdocx table MM2F_05_m08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2F_05_m08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(6,`c') = ("");
		putdocx table MM2F_05_m08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2F_05_m08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(7,`c') = ("");
		putdocx table MM2F_05_m08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_m08(8,`c') = ((r(mean)-(-0.8))/(-0.8)), nformat(%4.3f);
		putdocx table MM2F_05_m08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_m08(8,`c') = ("");
		putdocx table MM2F_05_m08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2F_05_m08, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2F 0.5 0.9;

sum;

putdocx begin;
putdocx table MM2F_05_09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2F_05_09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(1,`c') = ("");
		putdocx table MM2F_05_09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2F_05_09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(2,`c') = ("");
		putdocx table MM2F_05_09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2F_05_09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(3,`c') = ("");
		putdocx table MM2F_05_09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2F_05_09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(4,`c') = ("");
		putdocx table MM2F_05_09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM2F_05_09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(5,`c') = ("");
		putdocx table MM2F_05_09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2F_05_09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(6,`c') = ("");
		putdocx table MM2F_05_09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2F_05_09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(7,`c') = ("");
		putdocx table MM2F_05_09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2F_05_09(8,`c') = ((r(mean)-0.9)/0.9), nformat(%4.3f);
		putdocx table MM2F_05_09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_05_09(8,`c') = ("");
		putdocx table MM2F_05_09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2F_05_09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2F 2.18 -0.9;

sum;

putdocx begin;
putdocx table MM2F_218_m09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2F_218_m09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(1,`c') = ("");
		putdocx table MM2F_218_m09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2F_218_m09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(2,`c') = ("");
		putdocx table MM2F_218_m09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2F_218_m09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(3,`c') = ("");
		putdocx table MM2F_218_m09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2F_218_m09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(4,`c') = ("");
		putdocx table MM2F_218_m09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM2F_218_m09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(5,`c') = ("");
		putdocx table MM2F_218_m09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2F_218_m09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(6,`c') = ("");
		putdocx table MM2F_218_m09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2F_218_m09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(7,`c') = ("");
		putdocx table MM2F_218_m09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m09(8,`c') = ((r(mean)-(-0.9))/(-0.9)), nformat(%4.3f);
		putdocx table MM2F_218_m09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m09(8,`c') = ("");
		putdocx table MM2F_218_m09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2F_218_m09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2F 2.18 -0.8;

sum;

putdocx begin;
putdocx table MM2F_218_m08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2F_218_m08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(1,`c') = ("");
		putdocx table MM2F_218_m08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2F_218_m08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(2,`c') = ("");
		putdocx table MM2F_218_m08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2F_218_m08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(3,`c') = ("");
		putdocx table MM2F_218_m08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2F_218_m08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(4,`c') = ("");
		putdocx table MM2F_218_m08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM2F_218_m08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(5,`c') = ("");
		putdocx table MM2F_218_m08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2F_218_m08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(6,`c') = ("");
		putdocx table MM2F_218_m08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2F_218_m08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(7,`c') = ("");
		putdocx table MM2F_218_m08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_m08(8,`c') = ((r(mean)-(-0.8))/(-0.8)), nformat(%4.3f);
		putdocx table MM2F_218_m08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_m08(8,`c') = ("");
		putdocx table MM2F_218_m08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2F_218_m08, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM2F 2.18 0.9;

sum;

putdocx begin;
putdocx table MM2F_218_09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM2F_218_09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(1,`c') = ("");
		putdocx table MM2F_218_09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM2F_218_09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(2,`c') = ("");
		putdocx table MM2F_218_09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM2F_218_09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(3,`c') = ("");
		putdocx table MM2F_218_09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM2F_218_09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(4,`c') = ("");
		putdocx table MM2F_218_09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM2F_218_09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(5,`c') = ("");
		putdocx table MM2F_218_09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM2F_218_09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(6,`c') = ("");
		putdocx table MM2F_218_09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM2F_218_09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(7,`c') = ("");
		putdocx table MM2F_218_09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM2F_218_09(8,`c') = ((r(mean)-0.9)/0.9), nformat(%4.3f);
		putdocx table MM2F_218_09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM2F_218_09(8,`c') = ("");
		putdocx table MM2F_218_09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM2F_218_09, replace;

clear;

*Table 6, third panel;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3F 0.5 -0.9;

sum;

putdocx begin;
putdocx table MM3F_05_m09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3F_05_m09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(1,`c') = ("");
		putdocx table MM3F_05_m09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3F_05_m09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(2,`c') = ("");
		putdocx table MM3F_05_m09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3F_05_m09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(3,`c') = ("");
		putdocx table MM3F_05_m09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3F_05_m09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(4,`c') = ("");
		putdocx table MM3F_05_m09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM3F_05_m09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(5,`c') = ("");
		putdocx table MM3F_05_m09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3F_05_m09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(6,`c') = ("");
		putdocx table MM3F_05_m09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3F_05_m09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(7,`c') = ("");
		putdocx table MM3F_05_m09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m09(8,`c') = ((r(mean)-(-0.9))/(-0.9)), nformat(%4.3f);
		putdocx table MM3F_05_m09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m09(8,`c') = ("");
		putdocx table MM3F_05_m09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3F_05_m09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3F 0.5 -0.8;

sum;

putdocx begin;
putdocx table MM3F_05_m08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3F_05_m08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(1,`c') = ("");
		putdocx table MM3F_05_m08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3F_05_m08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(2,`c') = ("");
		putdocx table MM3F_05_m08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3F_05_m08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(3,`c') = ("");
		putdocx table MM3F_05_m08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3F_05_m08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(4,`c') = ("");
		putdocx table MM3F_05_m08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM3F_05_m08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(5,`c') = ("");
		putdocx table MM3F_05_m08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3F_05_m08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(6,`c') = ("");
		putdocx table MM3F_05_m08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3F_05_m08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(7,`c') = ("");
		putdocx table MM3F_05_m08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_m08(8,`c') = ((r(mean)-(-0.8))/(-0.8)), nformat(%4.3f);
		putdocx table MM3F_05_m08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_m08(8,`c') = ("");
		putdocx table MM3F_05_m08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3F_05_m08, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3F 0.5 0.9;

sum;

putdocx begin;
putdocx table MM3F_05_09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3F_05_09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(1,`c') = ("");
		putdocx table MM3F_05_09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3F_05_09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(2,`c') = ("");
		putdocx table MM3F_05_09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3F_05_09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(3,`c') = ("");
		putdocx table MM3F_05_09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3F_05_09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(4,`c') = ("");
		putdocx table MM3F_05_09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(5,`c') = ((r(mean)-0.5)/0.5), nformat(%4.3f);
		putdocx table MM3F_05_09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(5,`c') = ("");
		putdocx table MM3F_05_09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3F_05_09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(6,`c') = ("");
		putdocx table MM3F_05_09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3F_05_09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(7,`c') = ("");
		putdocx table MM3F_05_09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3F_05_09(8,`c') = ((r(mean)-0.9)/0.9), nformat(%4.3f);
		putdocx table MM3F_05_09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_05_09(8,`c') = ("");
		putdocx table MM3F_05_09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3F_05_09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3F 2.18 -0.9;

sum;

putdocx begin;
putdocx table MM3F_218_m09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3F_218_m09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(1,`c') = ("");
		putdocx table MM3F_218_m09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3F_218_m09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(2,`c') = ("");
		putdocx table MM3F_218_m09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3F_218_m09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(3,`c') = ("");
		putdocx table MM3F_218_m09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3F_218_m09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(4,`c') = ("");
		putdocx table MM3F_218_m09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM3F_218_m09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(5,`c') = ("");
		putdocx table MM3F_218_m09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3F_218_m09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(6,`c') = ("");
		putdocx table MM3F_218_m09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3F_218_m09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(7,`c') = ("");
		putdocx table MM3F_218_m09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m09(8,`c') = ((r(mean)-(-0.9))/(-0.9)), nformat(%4.3f);
		putdocx table MM3F_218_m09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m09(8,`c') = ("");
		putdocx table MM3F_218_m09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3F_218_m09, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3F 2.18 -0.8;

sum;

putdocx begin;
putdocx table MM3F_218_m08 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3F_218_m08(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(1,`c') = ("");
		putdocx table MM3F_218_m08(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3F_218_m08(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(2,`c') = ("");
		putdocx table MM3F_218_m08(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3F_218_m08(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(3,`c') = ("");
		putdocx table MM3F_218_m08(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3F_218_m08(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(4,`c') = ("");
		putdocx table MM3F_218_m08(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM3F_218_m08(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(5,`c') = ("");
		putdocx table MM3F_218_m08(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3F_218_m08(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(6,`c') = ("");
		putdocx table MM3F_218_m08(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3F_218_m08(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(7,`c') = ("");
		putdocx table MM3F_218_m08(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_m08(8,`c') = ((r(mean)-(-0.8))/(-0.8)), nformat(%4.3f);
		putdocx table MM3F_218_m08(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_m08(8,`c') = ("");
		putdocx table MM3F_218_m08(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3F_218_m08, replace;

clear;

simulate b1_1_=r(b10_PP_Heckprobit) b2_1_=r(b11_PP_Heckprobit) b3_1_=r(b12_PP_Heckprobit) b4_1_=r(b13_PP_Heckprobit) b5_1_=r(b20_PP_Heckprobit) b6_1_=r(b21_PP_Heckprobit) b7_1_=r(b22_PP_Heckprobit) b8_1_=r(rho_PP_Heckprobit), reps(500) seed(376): MM3F 2.18 0.9;

sum;

putdocx begin;
putdocx table MM3F_218_09 = (8,2); /*needs to specify value of beta20 in row 5 and of rho in row 8*/
forvalues c = 1(1)1 {;
	capture summarize b1_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(1,`c') = ((r(mean)-(-1))/(-1)), nformat(%4.3f);
		putdocx table MM3F_218_09(1,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(1,`c') = ("");
		putdocx table MM3F_218_09(1,`=`c'+1') = ("");
	};
	capture summarize b2_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(2,`c') = ((r(mean)-0.2)/0.2), nformat(%4.3f);
		putdocx table MM3F_218_09(2,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(2,`c') = ("");
		putdocx table MM3F_218_09(2,`=`c'+1') = ("");
	};
	capture summarize b3_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(3,`c') = ((r(mean)-1.5)/1.5), nformat(%4.3f);
		putdocx table MM3F_218_09(3,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(3,`c') = ("");
		putdocx table MM3F_218_09(3,`=`c'+1') = ("");
	};
	capture summarize b4_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(4,`c') = ((r(mean)-(-0.6))/(-0.6)), nformat(%4.3f);
		putdocx table MM3F_218_09(4,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(4,`c') = ("");
		putdocx table MM3F_218_09(4,`=`c'+1') = ("");
	};
	capture summarize b5_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(5,`c') = ((r(mean)-2.18)/2.18), nformat(%4.3f);
		putdocx table MM3F_218_09(5,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(5,`c') = ("");
		putdocx table MM3F_218_09(5,`=`c'+1') = ("");
	};
	capture summarize b6_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(6,`c') = ((r(mean)-0.8)/0.8), nformat(%4.3f);
		putdocx table MM3F_218_09(6,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(6,`c') = ("");
		putdocx table MM3F_218_09(6,`=`c'+1') = ("");
	};
	capture summarize b7_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(7,`c') = ((r(mean)-(-0.5))/(-0.5)), nformat(%4.3f);
		putdocx table MM3F_218_09(7,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(7,`c') = ("");
		putdocx table MM3F_218_09(7,`=`c'+1') = ("");
	};
	capture summarize b8_`c'_;
	if _rc==0 {;
		putdocx table MM3F_218_09(8,`c') = ((r(mean)-0.9)/0.9), nformat(%4.3f);
		putdocx table MM3F_218_09(8,`=`c'+1') = (r(sd)), nformat(%4.3f);
	};
	else {;
		putdocx table MM3F_218_09(8,`c') = ("");
		putdocx table MM3F_218_09(8,`=`c'+1') = ("");
	};
};
putdocx save Table_MM3F_218_09, replace;

clear all;